@@ -24,6 +24,7 @@
 #include <ebml/EbmlMaster.h>
 #undef min
 
+#include <boost/foreach.hpp>
 #include <boost/format.hpp>
 #include <string>
 
@@ -49,8 +50,6 @@ namespace libebml {
 
 using namespace libebml;
 
-#define VERSIONNAME "C'est le bon"
-#define VERSIONINFO "mkvmerge v" VERSION " ('" VERSIONNAME "')"
 #define BUGMSG Y("This should not have happened. Please contact the author " \
                  "Moritz Bunkus <moritz@bunkus.org> with this error/warning " \
                  "message, a description of what you were trying to do, " \
@@ -77,11 +76,13 @@ void MTX_DLL_API set_process_priority(int priority);
 
 extern int MTX_DLL_API verbose;
 
+#define foreach                  BOOST_FOREACH
+#define reverse_foreach          BOOST_REVERSE_FOREACH
 #define mxforeach(it, vec)       for (it = (vec).begin(); it != (vec).end(); it++)
 #define mxfind(value, cont)      std::find(cont.begin(), cont.end(), value)
 #define mxfind2(it, value, cont) ((it = std::find((cont).begin(), (cont).end(), value)) != (cont).end())
 #define map_has_key(m, k)        ((m).end() != (m).find(k))
 
-void mtx_common_cleanup();
+void MTX_DLL_API mtx_common_init();
 
 #endif // __MTX_COMMON_H
