@@ -11,17 +11,17 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __ERROR_H
-#define __ERROR_H
+#ifndef __MTX_COMMON_ERROR_H
+#define __MTX_COMMON_ERROR_H
 
-#include <string>
-#include <boost/format.hpp>
+#include "os.h"
+
+#include "common/common.h"
 
-using namespace std;
 
 class MTX_DLL_API error_c {
 protected:
-  string error;
+  std::string error;
 
 public:
   error_c():
@@ -32,7 +32,7 @@ public:
     error(_error) {
   }
 
-  error_c(const string &_error):
+  error_c(const std::string &_error):
     error(_error) {
   }
 
@@ -43,9 +43,9 @@ public:
   virtual ~error_c() {
   }
 
-  virtual string get_error() const {
+  virtual std::string get_error() const {
     return error;
   }
 };
 
-#endif // __ERROR_H
+#endif // __MTX_COMMON_ERROR_H
