@@ -12,24 +12,24 @@
    Changes by Robert Millan <rmh@aybabtu.com>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
 #include <algorithm>
-
-#include "common.h"
-#include "extern_data.h"
-#include "mm_io.h"
-
-#ifdef SYS_WINDOWS
-# include "os_windows.h"
-#endif
-
 #if HAVE_MAGIC_H
 extern "C" {
 #include <magic.h>
 };
 #endif
 
+#include "common/common.h"
+#include "common/extern_data.h"
+#include "common/mm_io.h"
+#include "common/strings/editing.h"
+
+#ifdef SYS_WINDOWS
+# include "os_windows.h"
+#endif
+
 #ifndef NULL
 # define NULL 0
 #endif
@@ -2613,9 +2613,9 @@ const char *cctlds[] = {
   NULL
 };
 
-static string
-guess_mime_type_by_ext(string ext) {
-  vector<string> extensions;
+static std::string
+guess_mime_type_by_ext(std::string ext) {
+  std::vector<std::string> extensions;
   int i, j;
 
   /* chop off basename */
@@ -2658,10 +2658,10 @@ guess_mime_type_by_content(magic_t &m,
       if (buf->get_size() < (buffer_size + bytes_to_read))
         buf->resize(buffer_size + bytes_to_read);
 
-      int64_t bytes_read     = file.read(buf->get() + buffer_size, bytes_to_read);
+      int64_t bytes_read     = file.read(buf->get_buffer() + buffer_size, bytes_to_read);
       buffer_size           += bytes_read;
 
-      std::string mime_type  = magic_buffer(m, buf->get(), buffer_size);
+      std::string mime_type  = magic_buffer(m, buf->get_buffer(), buffer_size);
 
       if (!mime_type.empty())
         return mime_type;
@@ -2673,11 +2673,11 @@ guess_mime_type_by_content(magic_t &m,
 }
 #endif  // HAVE_MAGIC_H
 
-string
-guess_mime_type(string ext,
+std::string
+guess_mime_type(std::string ext,
                 bool is_file) {
 #if HAVE_MAGIC_H
-  string ret;
+  std::string ret;
   magic_t m;
 
   if (!is_file)
@@ -2725,7 +2725,7 @@ guess_mime_type(string ext,
 }
 
 bool
-is_valid_cctld(const string &s) {
+is_valid_cctld(const std::string &s) {
   int i;
 
   for (i = 0; NULL != cctlds[i]; ++i)
