@@ -11,16 +11,17 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
 #include <string.h>
 
 #include <string>
 #include <vector>
 
-#include "base64.h"
-#include "common.h"
-#include "hacks.h"
+#include "common/base64.h"
+#include "common/common.h"
+#include "common/hacks.h"
+#include "common/strings/editing.h"
 
 static const struct {
   unsigned int id;
@@ -44,6 +45,7 @@ static const struct {
   { ENGAGE_ENABLE_TIMECODE_WARNING,      "enable_timecode_warning"      },
   { ENGAGE_MERGE_TRUEHD_FRAMES,          "merge_truehd_frames"          },
   { ENGAGE_REMOVE_BITSTREAM_AR_INFO,     "remove_bitstream_ar_info"     },
+  { ENGAGE_VOBSUB_SUBPIC_STOP_CMDS,      "vobsub_subpic_stop_cmds"      },
   { 0,                                   NULL },
 };
 static std::vector<bool> s_engaged_hacks(ENGAGE_MAX_IDX + 1, false);
@@ -66,7 +68,7 @@ engage_hacks(const std::string &hacks) {
       mxexit(0);
 
     } else if (engage_args[aidx] == "cow") {
-      const string initial = "ICAgICAgICAgIChfXykKICAgICAgICAgICgqKikg"
+      const std::string initial = "ICAgICAgICAgIChfXykKICAgICAgICAgICgqKikg"
         "IE9oIGhvbmV5LCB0aGF0J3Mgc28gc3dlZXQhCiAgIC8tLS0tLS0tXC8gICBPZiB"
         "jb3Vyc2UgSSdsbCBtYXJyeSB5b3UhCiAgLyB8ICAgICB8fAogKiAgfHwtLS0tfH"
         "wKICAgIF5eICAgIF5eCg==";
