@@ -31,7 +31,9 @@
 using namespace libebml;
 using namespace libmatroska;
 
-#define in_parent(p) (m_file->getFilePointer() < (p->GetElementPosition() + p->ElementSize()))
+#define in_parent(p) (!p->IsFiniteSize() || (m_file->getFilePointer() < (p->GetElementPosition() + p->ElementSize())))
+
+#define CONSOLE_PERCENTAGE_WIDTH 25
 
 bool
 operator <(const kax_analyzer_data_cptr &d1,
@@ -103,7 +105,7 @@ kax_analyzer_c::debug_dump_elements_maybe(const std::string &hook_name) {
   if (!analyzer_debugging_requested(hook_name))
     return;
 
-  mxinfo(boost::format("kax_analyzer_%1% dumping elements:\n") % hook_name);
+  log_debug_message(boost::format("kax_analyzer_%1% dumping elements:\n") % hook_name);
   debug_dump_elements();
 }
 
@@ -221,17 +223,19 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode) {
     delete l0;
   }
 
-  m_segment          = counted_ptr<KaxSegment>(static_cast<KaxSegment *>(l0));
-  int upper_lvl_el   = 0;
-  bool aborted       = false;
-  bool cluster_found = false;
+  m_segment            = counted_ptr<KaxSegment>(static_cast<KaxSegment *>(l0));
+  int upper_lvl_el     = 0;
+  bool aborted         = false;
+  bool cluster_found   = false;
+  bool meta_seek_found = false;
 
   // We've got our segment, so let's find all level 1 elements.
   EbmlElement *l1 = m_stream->FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFFFFFFFFFLL, true, 1);
   while ((NULL != l1) && (0 >= upper_lvl_el)) {
     m_data.push_back(kax_analyzer_data_c::create(l1->Generic().GlobalId, l1->GetElementPosition(), l1->ElementSize(true)));
 
-    cluster_found |= is_id(l1, KaxCluster);
+    cluster_found   |= is_id(l1, KaxCluster);
+    meta_seek_found |= is_id(l1, KaxSeekHead);
 
     l1->SkipData(*m_stream, l1->Generic().Context);
     delete l1;
@@ -239,7 +243,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode) {
 
     aborted = !show_progress_running((int)(m_file->getFilePointer() * 100 / file_size));
 
-    if (!in_parent(m_segment) || aborted || (cluster_found && !parse_fully))
+    if (!in_parent(m_segment) || aborted || (cluster_found && meta_seek_found && !parse_fully))
       break;
 
     l1 = m_stream->FindNextElement(m_segment->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true);
@@ -298,6 +302,8 @@ kax_analyzer_c::read_element(kax_analyzer_data_c *element_data) {
 kax_analyzer_c::update_element_result_e
 kax_analyzer_c::update_element(EbmlElement *e,
                                bool write_defaults) {
+  fix_mandatory_elements(e);
+
   try {
     call_and_validate({},                                             "update_element_0");
     call_and_validate(overwrite_all_instances(e->Generic().GlobalId), "update_element_1");
@@ -972,3 +978,62 @@ kax_analyzer_c::fix_element_sizes(int64_t file_size) {
     if (-1 == m_data[i]->m_size)
       m_data[i]->m_size = ((i + 1) < m_data.size() ? m_data[i + 1]->m_pos : file_size) - m_data[i]->m_pos;
 }
+
+// ------------------------------------------------------------
+
+bool m_show_progress;
+int m_previous_percentage;
+
+console_kax_analyzer_c::console_kax_analyzer_c(std::string file_name)
+  : kax_analyzer_c(file_name)
+  , m_show_progress(false)
+  , m_previous_percentage(-1)
+{
+}
+
+console_kax_analyzer_c::~console_kax_analyzer_c() {
+}
+
+void
+console_kax_analyzer_c::set_show_progress(bool show_progress) {
+  if (-1 == m_previous_percentage)
+    m_show_progress = show_progress;
+}
+
+void
+console_kax_analyzer_c::show_progress_start(int64_t size) {
+  if (!m_show_progress)
+    return;
+
+  m_previous_percentage = -1;
+  show_progress_running(0);
+}
+
+bool
+console_kax_analyzer_c::show_progress_running(int percentage) {
+  if (!m_show_progress || (percentage == m_previous_percentage))
+    return true;
+
+  std::string full_bar(        percentage  * CONSOLE_PERCENTAGE_WIDTH / 100, '=');
+  std::string empty_bar((100 - percentage) * CONSOLE_PERCENTAGE_WIDTH / 100, ' ');
+
+  mxinfo(boost::format(Y("Progress: [%1%%2%] %3%%%")) % full_bar % empty_bar % percentage);
+  mxinfo("\r");
+
+  m_previous_percentage = percentage;
+
+  return true;
+}
+
+void
+console_kax_analyzer_c::show_progress_done() {
+  if (!m_show_progress)
+    return;
+
+  show_progress_running(100);
+  mxinfo("\n");
+}
+
+void
+console_kax_analyzer_c::debug_abort_process() {
+}
