@@ -12,27 +12,24 @@
    Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#ifndef __SEGMENTINFO_H
-#define __SEGMENTINFO_H
+#ifndef __MTX_COMMON_SEGMENTINFO_H
+#define __MTX_COMMON_SEGMENTINFO_H
 
-#include <stdio.h>
+#include "os.h"
 
-#include "ebml/EbmlElement.h"
+#include <matroska/KaxInfo.h>
 
-#include "matroska/KaxInfo.h"
-#include "matroska/KaxInfoData.h"
-
-#include "common.h"
-#include "mm_io.h"
+#include "common/common.h"
+#include "common/mm_io.h"
 
 using namespace libebml;
 using namespace libmatroska;
 
-KaxInfo *MTX_DLL_API parse_segmentinfo(const string &file_name, bool exception_on_error = false);
+KaxInfo *MTX_DLL_API parse_segmentinfo(const std::string &file_name, bool exception_on_error = false);
 
 KaxInfo *MTX_DLL_API parse_xml_segmentinfo(mm_text_io_c *in, bool exception_on_error = false);
 
 void MTX_DLL_API fix_mandatory_segmentinfo_elements(EbmlElement *e);
 
-#endif // __SEGMENTINFO_H
+#endif // __MTX_COMMON_SEGMENTINFO_H
 
