@@ -54,6 +54,7 @@
 #include "common/strings/parsing.h"
 #include "common/tags/writer.h"
 #include "common/translation.h"
+#include "common/version.h"
 #include "common/xml/element_mapping.h"
 #include "extract/mkvextract.h"
 
@@ -144,7 +145,7 @@ set_usage() {
 "  -h, --help     Show this help.\n"
 "  -V, --version  Show version information.\n");
 
-  version_info = "mkvextract v" VERSION " ('" VERSIONNAME "')";
+  version_info = get_version_info("mkvextract", true);
 }
 
 static bool s_chapter_format_simple = false;
@@ -339,20 +340,10 @@ show_error(const std::string &error) {
 int
 main(int argc,
      char **argv) {
-  atexit(mtx_common_cleanup);
-
-  init_stdio();
-  init_locales();
+  mtx_common_init();
 
   set_process_priority(-1);
 
-  mm_file_io_c::setup();
-  srand(time(NULL));
-  g_cc_local_utf8 = charset_converter_c::init("");
-  init_cc_stdio();
-
-  xml_element_map_init();
-
   std::string input_file;
   operation_mode_e mode;
   std::vector<track_spec_t> tracks;
