@@ -10,13 +10,14 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
-#include "commonebml.h"
+#include "common/ebml.h"
+#include "common/endian.h"
+#include "common/math.h"
+#include "extract/xtr_avi.h"
 
-#include "xtr_avi.h"
-
-xtr_avi_c::xtr_avi_c(const string &codec_id,
+xtr_avi_c::xtr_avi_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -50,14 +51,14 @@ xtr_avi_c::create_file(xtr_base_c *master,
   if (NULL == m_avi)
     mxerror(boost::format(Y("The file '%1%' could not be opened for writing (%2%).\n")) % m_file_name % AVI_strerror());
 
-  string writing_app = "mkvextract";
+  std::string writing_app = "mkvextract";
   if (!g_no_variable_data)
     writing_app += (boost::format(" %1%") % VERSION).str();
   m_avi->writing_app = safestrdup(writing_app.c_str());
 
   char ccodec[5];
   memory_cptr mpriv = decode_codec_private(priv);
-  m_bih             = (alBITMAPINFOHEADER *)safememdup(mpriv->get(), mpriv->get_size());
+  m_bih             = (alBITMAPINFOHEADER *)safememdup(mpriv->get_buffer(), mpriv->get_size());
   memcpy(ccodec, &m_bih->bi_compression, 4);
   ccodec[4]         = 0;
 
@@ -83,7 +84,7 @@ xtr_avi_c::handle_frame(memory_cptr &frame,
     keyframe = (0 == bref);
 
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
-  AVI_write_frame(m_avi, (char *)frame->get(), frame->get_size(), keyframe);
+  AVI_write_frame(m_avi, (char *)frame->get_buffer(), frame->get_size(), keyframe);
 
   if (((double)duration / 1000000.0 - (1000.0 / m_fps)) >= 1.5) {
     int k;
