@@ -5,8 +5,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_avi.h 3461 2007-01-12 14:44:59Z mosu $
-
    extracts tracks from Matroska files into other files
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -15,28 +13,26 @@
 #ifndef __XTR_AVI_H
 #define __XTR_AVI_H
 
-#include "os.h"
+#include "common/os.h"
 
 extern "C" {
 #include <avilib.h>
 }
 
-#include "xtr_base.h"
+#include "extract/xtr_base.h"
 
 class xtr_avi_c: public xtr_base_c {
 public:
-  avi_t *avi;
-  double fps;
-  alBITMAPINFOHEADER *bih;
+  avi_t *m_avi;
+  double m_fps;
+  alBITMAPINFOHEADER *m_bih;
 
 public:
-  xtr_avi_c(const string &_codec_id, int64_t _tid, track_spec_t &tspec);
+  xtr_avi_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
-  virtual void create_file(xtr_base_c *_master, KaxTrackEntry &track);
-  virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions,
-                            int64_t timecode, int64_t duration, int64_t bref,
-                            int64_t fref, bool keyframe, bool discardable,
-                            bool references_valid);
+  virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
+  virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
+                            bool keyframe, bool discardable, bool references_valid);
   virtual void finish_file();
 
   virtual const char *get_container_name() {
