@@ -10,16 +10,18 @@
    Written by Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
 #include <matroska/KaxBlock.h>
 
-#include "common.h"
-#include "commonebml.h"
-#include "xtr_cpic.h"
-#include "r_corepicture.h"
+#include "common/common.h"
+#include "common/corepicture.h"
+#include "common/ebml.h"
+#include "common/endian.h"
+#include "common/strings/formatting.h"
+#include "extract/xtr_cpic.h"
 
-xtr_cpic_c::xtr_cpic_c(const string &codec_id,
+xtr_cpic_c::xtr_cpic_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -40,7 +42,7 @@ xtr_cpic_c::handle_frame(memory_cptr &frame,
                          bool references_valid) {
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
-  binary *mybuffer = frame->get();
+  binary *mybuffer = frame->get_buffer();
   int data_size    = frame->get_size();
   if (2 > data_size) {
     mxinfo(boost::format(Y("CorePicture frame %1% not supported.\n")) % m_frame_counter);
@@ -55,7 +57,7 @@ xtr_cpic_c::handle_frame(memory_cptr &frame,
     return;
   }
 
-  string frame_file_name = m_file_name_root + "_" + to_string(m_frame_counter);
+  std::string frame_file_name = m_file_name_root + "_" + to_string(m_frame_counter);
   if (7 == header_size) {
     uint8 picture_type = mybuffer[6];
     if (COREPICTURE_TYPE_JPEG == picture_type)
