@@ -12,14 +12,14 @@
    Mike Matsnev <mike@po.cs.msu.su>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
-#include "checksums.h"
-#include "commonebml.h"
-#include "iso639.h"
-#include "smart_pointers.h"
-#include "tta_common.h"
-#include "xtr_vobsub.h"
+#include "common/checksums.h"
+#include "common/ebml.h"
+#include "common/iso639.h"
+#include "common/smart_pointers.h"
+#include "common/tta.h"
+#include "extract/xtr_vobsub.h"
 
 #if defined(COMP_MSC)
 #pragma pack(push,1)
@@ -44,7 +44,7 @@ struct PACKED_STRUCTURE mpeg_ps_header_t {
 #pragma pack(pop)
 #endif
 
-xtr_vobsub_c::xtr_vobsub_c(const string &codec_id,
+xtr_vobsub_c::xtr_vobsub_c(const std::string &codec_id,
                            int64_t tid,
                            track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -72,7 +72,7 @@ xtr_vobsub_c::create_file(xtr_base_c *master,
   m_language = kt_get_language(track);
 
   if (NULL == master) {
-    string sub_file_name = m_base_name + ".sub";
+    std::string sub_file_name = m_base_name + ".sub";
 
     try {
       m_out = new mm_file_io_c(sub_file_name, MODE_CREATE);
@@ -87,7 +87,7 @@ xtr_vobsub_c::create_file(xtr_base_c *master,
       mxerror(boost::format(Y("Cannot extract tracks of different kinds to the same file. This was requested for the tracks %1% and %2%.\n"))
               % m_tid % m_master->m_tid);
 
-    if ((m_private_data->get_size() != vmaster->m_private_data->get_size()) || memcmp(priv->GetBuffer(), vmaster->m_private_data->get(), m_private_data->get_size()))
+    if ((m_private_data->get_size() != vmaster->m_private_data->get_size()) || memcmp(priv->GetBuffer(), vmaster->m_private_data->get_buffer(), m_private_data->get_size()))
       mxerror(boost::format(Y("Two VobSub tracks can only be extracted into the same file if their CodecPrivate data matches. "
                               "This is not the case for the tracks %1% and %2%.\n")) % m_tid % m_master->m_tid);
 
@@ -113,7 +113,7 @@ xtr_vobsub_c::handle_frame(memory_cptr &frame,
 
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
-  unsigned char *data = frame->get();
+  unsigned char *data = frame->get_buffer();
   int size            = frame->get_size();
 
   m_positions.push_back(vmaster->m_out->getFilePointer());
@@ -138,8 +138,6 @@ xtr_vobsub_c::handle_frame(memory_cptr &frame,
   ps.muxr[1] = 0x89;
   ps.muxr[2] = 0xc3; // just some value
   ps.stlen   = 0xf8;
-  if ((8 > padding) && (first == size))
-    ps.stlen |= (uint8_t)padding;
 
   mpeg_es_header_t es;
   memset(&es, 0, sizeof(mpeg_es_header_t));
@@ -156,11 +154,17 @@ xtr_vobsub_c::handle_frame(memory_cptr &frame,
   es.pts[3]    = (uint8_t)(c >> 7);
   es.pts[4]    = (uint8_t)(c << 1) | 0x01;
   es.lidx      = (NULL == m_master) ? 0x20 : m_stream_id;
+  if ((6 > padding) && (first == size)) {
+    es.hlen += (uint8_t)padding;
+    es.len[0]  = (uint8_t)((first + 9 + padding) >> 8);
+    es.len[1]  = (uint8_t)(first + 9 + padding);
+  }
 
   vmaster->m_out->write(&ps, sizeof(mpeg_ps_header_t));
-  if ((0 < padding) && (8 > padding) && (first == size))
+  vmaster->m_out->write(&es, sizeof(mpeg_es_header_t) - 1);
+  if ((0 < padding) && (6 > padding) && (first == size))
     vmaster->m_out->write(padding_data, padding);
-  vmaster->m_out->write(&es, sizeof(mpeg_es_header_t));
+  vmaster->m_out->write(&es.lidx, 1);
   vmaster->m_out->write(data, first);
   while (first < size) {
     size    -= first;
@@ -169,22 +173,24 @@ xtr_vobsub_c::handle_frame(memory_cptr &frame,
     padding  = (2048 - (size + 10 + sizeof(mpeg_ps_header_t))) & 2047;
     first    = size + 10 + sizeof(mpeg_ps_header_t) > 2048 ? 2048 - 10 - sizeof(mpeg_ps_header_t) : size;
 
-    if ((8 > padding) && (first == size))
-      ps.stlen |= (uint8_t)padding;
-
     es.len[0]   = (uint8_t)((first + 4) >> 8);
     es.len[1]   = (uint8_t)(first + 4);
     es.flags[1] = 0;
     es.hlen     = 0;
-    es.pts[0]   = es.lidx;
+    if ((6 > padding) && (first == size)) {
+      es.hlen += (uint8_t)padding;
+      es.len[0]  = (uint8_t)((first + 4 + padding) >> 8);
+      es.len[1]  = (uint8_t)(first + 4 + padding);
+    }
 
     vmaster->m_out->write(&ps, sizeof(mpeg_ps_header_t));
-    if ((0 < padding) && (8 > padding) && (first == size))
+    vmaster->m_out->write(&es, 9);
+    if ((0 < padding) && (6 > padding) && (first == size))
       vmaster->m_out->write(padding_data, padding);
-    vmaster->m_out->write(&es, 10);
+    vmaster->m_out->write(&es.lidx, 1);
     vmaster->m_out->write(data, first);
   }
-  if (8 <= padding) {
+  if (6 <= padding) {
     padding      -= 6;
     es.stream_id  = 0xbe;
     es.len[0]     = (uint8_t)(padding >> 8);
@@ -216,9 +222,9 @@ xtr_vobsub_c::finish_file() {
     mm_file_io_c idx(m_base_name, MODE_CREATE);
     mxinfo(boost::format(Y("Writing the VobSub index file '%1%'.\n")) % m_base_name);
 
-    if ((25 > m_private_data->get_size()) || strncasecmp((char *)m_private_data->get(), header_line, 25))
+    if ((25 > m_private_data->get_size()) || strncasecmp((char *)m_private_data->get_buffer(), header_line, 25))
       idx.puts(header_line);
-    idx.write(m_private_data->get(), m_private_data->get_size());
+    idx.write(m_private_data->get_buffer(), m_private_data->get_size());
 
     write_idx(idx, 0);
     int slave;
