@@ -13,22 +13,21 @@
 #ifndef __XTR_VOBSUB_H
 #define __XTR_VOBSUB_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "smart_pointers.h"
-
-#include "xtr_base.h"
+#include "common/smart_pointers.h"
+#include "extract/xtr_base.h"
 
 class xtr_vobsub_c: public xtr_base_c {
 public:
-  vector<int64_t> m_positions, m_timecodes;
-  vector<xtr_vobsub_c *> m_slaves;
+  std::vector<int64_t> m_positions, m_timecodes;
+  std::vector<xtr_vobsub_c *> m_slaves;
   memory_cptr m_private_data;
-  string m_base_name, m_language;
+  std::string m_base_name, m_language;
   int m_stream_id;
 
 public:
-  xtr_vobsub_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_vobsub_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
