@@ -31,10 +31,6 @@
 using namespace libebml;
 using namespace libmatroska;
 
-#if ! wxCHECK_VERSION(2,4,2)
-# define wxTreeItemIdValue long
-#endif
-
 mi_frame *frame;
 
 enum {
@@ -53,14 +49,9 @@ mi_app::OnInit() {
 
   setup();
 
-#if WXUNICODE
   int i;
-
   for (i = 1; i < argc; i++)
     args.push_back(std::string(wxMB(wxString(argv[i]))));
-#else
-  args = command_line_utf8(argc, argv);
-#endif
 
   parse_args(args, initial_file);
 
@@ -348,7 +339,7 @@ mi_frame::on_help_about(wxCommandEvent &WXUNUSED(event)) {
                  "<moritz@bunkus.org>.\nSources and the latest binaries are "
                  "always available at\nhttp://www.bunkus.org/videotools/"
                  "mkvtoolnix/"),
-             wxCS2WS(EbmlCodeVersion), wxCS2WS(KaxCodeVersion));
+             wxUCS(EbmlCodeVersion), wxUCS(KaxCodeVersion));
   wxMessageBox(msg, wxT("About mkvinfo"), wxOK | wxICON_INFORMATION, this);
 }
 
