@@ -81,6 +81,7 @@ extern "C" {
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/translation.h"
+#include "common/version.h"
 #include "common/xml/element_mapping.h"
 #include "info/mkvinfo.h"
 
@@ -210,7 +211,7 @@ set_usage() {
       "  -h, --help     Show this help.\n"
       "  -V, --version  Show version information.\n");
 
-  version_info = (boost::format("mkvinfo v%1% ('%2%')") % VERSION % VERSIONNAME).str();
+  version_info = get_version_info("mkvinfo", true);
 }
 
 #define UTF2STR(s)                 UTFstring_to_cstrutf8(UTFstring(s))
@@ -1922,17 +1923,10 @@ process_file(const std::string &file_name) {
 
 void
 setup(const std::string &locale) {
-  atexit(mtx_common_cleanup);
+  mtx_common_init();
 
-  init_stdio();
   init_locales(locale);
 
-  mm_file_io_c::setup();
-  g_cc_local_utf8 = charset_converter_c::init("");
-  init_cc_stdio();
-
-  xml_element_map_init();
-
   init_common_boost_formats();
 }
 
