@@ -24,6 +24,7 @@
 
 #include "common/common.h"
 #include "common/translation.h"
+#include "common/version.h"
 #include "common/wx.h"
 #include "info/wxwidgets_ui.h"
 #if !defined(SYS_WINDOWS)
@@ -34,10 +35,6 @@
 using namespace libebml;
 using namespace libmatroska;
 
-#if ! wxCHECK_VERSION(2,4,2)
-# define wxTreeItemIdValue long
-#endif
-
 static mi_frame *frame;
 
 enum {
@@ -80,14 +77,9 @@ mi_app::OnInit() {
 
   setup(get_ui_locale());
 
-#if WXUNICODE
   int i;
-
   for (i = 1; i < argc; i++)
     args.push_back(std::string(wxMB(wxString(argv[i]))));
-#else
-  args = command_line_utf8(argc, argv);
-#endif
 
   parse_args(args, initial_file);
 
@@ -359,7 +351,7 @@ mi_frame::on_help_about(wxCommandEvent &WXUNUSED(event)) {
                "<moritz@bunkus.org>.\nSources and the latest binaries are "
                "always available at\nhttp://www.bunkus.org/videotools/"
                "mkvtoolnix/"),
-             wxUCS(VERSIONINFO), wxCS2WS(EbmlCodeVersion), wxCS2WS(KaxCodeVersion));
+             wxUCS(get_version_info("mkvinfo GUI")), wxUCS(EbmlCodeVersion), wxUCS(KaxCodeVersion));
   wxMessageBox(msg, Z("About mkvinfo"), wxOK | wxICON_INFORMATION, this);
 }
 
