@@ -11,7 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -23,14 +23,14 @@
 #include <list>
 #include <memory>
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "error.h"
-#include "output_control.h"
-#include "r_avc.h"
-#include "p_avc.h"
+#include "common/byte_buffer.h"
+#include "common/common.h"
+#include "common/error.h"
+#include "common/memory.h"
+#include "input/r_avc.h"
+#include "merge/output_control.h"
+#include "output/p_avc.h"
 
-using namespace std;
 
 #define PROBESIZE 4
 #define READ_SIZE 1024 * 1024
@@ -56,16 +56,16 @@ avc_es_reader_c::probe_file(mm_io_c *io,
 
     io->setFilePointer(0, seek_beginning);
     for (i = 0; MAX_PROBE_BUFFERS > i; ++i) {
-      num_read = io->read(buf->get(), READ_SIZE);
+      num_read = io->read(buf->get_buffer(), READ_SIZE);
       if (4 > num_read)
         return 0;
 
       // MPEG TS starts with 0x47.
-      if (first && (0x47 == buf->get()[0]))
+      if (first && (0x47 == buf->get_buffer()[0]))
         return 0;
       first = false;
 
-      parser.add_bytes(buf->get(), num_read);
+      parser.add_bytes(buf->get_buffer(), num_read);
 
       if (parser.headers_parsed())
         return 1;
@@ -103,10 +103,10 @@ avc_es_reader_c::avc_es_reader_c(track_info_c &n_ti)
     int num_read, i;
 
     for (i = 0; MAX_PROBE_BUFFERS > i; ++i) {
-      num_read = m_io->read(m_buffer->get(), READ_SIZE);
+      num_read = m_io->read(m_buffer->get_buffer(), READ_SIZE);
       if (0 == num_read)
         throw error_c(Y("avc_es_reader: Should not have happened."));
-      parser.add_bytes(m_buffer->get(), num_read);
+      parser.add_bytes(m_buffer->get_buffer(), num_read);
       if (parser.headers_parsed())
         break;
     }
@@ -146,11 +146,11 @@ avc_es_reader_c::read(generic_packetizer_c *,
   if (m_bytes_processed >= m_size)
     return FILE_STATUS_DONE;
 
-  num_read = m_io->read(m_buffer->get(), READ_SIZE);
+  num_read = m_io->read(m_buffer->get_buffer(), READ_SIZE);
   if (0 >= num_read)
     return FILE_STATUS_DONE;
 
-  PTZR0->process(new packet_t(new memory_c(m_buffer->get(), num_read)));
+  PTZR0->process(new packet_t(new memory_c(m_buffer->get_buffer(), num_read)));
 
   m_bytes_processed += num_read;
 
