@@ -11,20 +11,17 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <ogg/ogg.h>
 #include <vorbis/codec.h>
 
-#include "common.h"
-#include "flac_common.h"
-#include "matroska.h"
-#include "output_control.h"
-#include "pr_generic.h"
-#include "r_flac.h"
+#include "common/common.h"
+#include "common/matroska.h"
+#include "input/flac_common.h"
+#include "input/r_flac.h"
+#include "merge/output_control.h"
+#include "merge/pr_generic.h"
 
 #define BUFFER_SIZE 4096
 
@@ -384,7 +381,10 @@ flac_reader_c::parse_file() {
 #endif  // HAVE_FLAC_DECODER_SKIP
   }
 
-  mxinfo(Y("+-> Pre-parsing FLAC file: 100%\n"));
+  if (100 != old_progress)
+    mxinfo(Y("+-> Pre-parsing FLAC file: 100%\n"));
+  else
+    mxinfo("\n");
 
   if ((blocks.size() == 0) || (blocks[0].type != FLAC_BLOCK_TYPE_HEADERS))
     mxerror(Y("flac_reader: Could not read all header packets.\n"));
@@ -567,7 +567,7 @@ flac_reader_c::probe_file(mm_io_c *io,
     return 0;
   try {
     io->setFilePointer(0, seek_beginning);
-    if (4 != io->read(data, 4) != 4)
+    if (io->read(data, 4) != 4)
       return 0;
     io->setFilePointer(0, seek_beginning);
   } catch (...) {
