@@ -14,9 +14,10 @@
 #ifndef __R_FLAC_H
 #define __R_FLAC_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "mm_io.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
 
 #if defined(HAVE_FLAC_FORMAT_H)
 #include <vector>
@@ -33,7 +34,7 @@
 # include <FLAC/stream_decoder.h>
 #endif
 
-#include "p_flac.h"
+#include "output/p_flac.h"
 
 #define FLAC_BLOCK_TYPE_HEADERS 0
 #define FLAC_BLOCK_TYPE_DATA    1
@@ -51,8 +52,8 @@ private:
   int64_t samples, file_size;
   unsigned char *header;
   int header_size;
-  vector<flac_block_t> blocks;
-  vector<flac_block_t>::iterator current_block;
+  std::vector<flac_block_t> blocks;
+  std::vector<flac_block_t>::iterator current_block;
   FLAC__StreamMetadata_StreamInfo stream_info;
 
 public:
