@@ -99,6 +99,30 @@ using namespace libmatroska;
 
 #define MAGIC_MKV 0x1a45dfa3
 
+void
+kax_track_t::handle_packetizer_display_dimensions() {
+  // If user hasn't set an aspect ratio via the command line and the
+  // source file provides display width/height paramaters then use
+  // these and signal the packetizer not to extract the dimensions
+  // from the bitstream.
+  if ((0 == v_dwidth) || (0 == v_dheight))
+    return;
+
+  ptzr_ptr->set_video_display_dimensions(v_dwidth, v_dheight, PARAMETER_SOURCE_CONTAINER);
+}
+
+void
+kax_track_t::handle_packetizer_pixel_cropping() {
+  if ((0 < v_pcleft) || (0 < v_pctop) || (0 < v_pcright) || (0 < v_pcbottom))
+    ptzr_ptr->set_video_pixel_cropping(v_pcleft, v_pctop, v_pcright, v_pcbottom, PARAMETER_SOURCE_CONTAINER);
+}
+
+void
+kax_track_t::handle_packetizer_stereo_mode() {
+  if (STEREO_MODE_UNSPECIFIED != v_stereo_mode)
+    ptzr_ptr->set_video_stereo_mode(v_stereo_mode, PARAMETER_SOURCE_CONTAINER);
+}
+
 /*
    Probes a file by simply comparing the first four bytes to the EBML
    head signature.
@@ -1219,6 +1243,7 @@ kax_reader_c::init_passthrough_packetizer(kax_track_t *t) {
 
   ptzr                    = new passthrough_packetizer_c(this, nti);
   t->ptzr                 = add_packetizer(ptzr);
+  t->ptzr_ptr             = ptzr;
   t->passthrough          = true;
   ptzr_to_track_map[ptzr] = t;
 
@@ -1236,16 +1261,11 @@ kax_reader_c::init_passthrough_packetizer(kax_track_t *t) {
   if ('v' == t->type) {
     ptzr->set_video_pixel_width(t->v_width);
     ptzr->set_video_pixel_height(t->v_height);
-    if (!ptzr->ti.aspect_ratio_given) { // The user hasn't set it.
-      if (0 != t->v_dwidth)
-        ptzr->set_video_display_width(t->v_dwidth);
-      if (0 != t->v_dheight)
-        ptzr->set_video_display_height(t->v_dheight);
-    }
-    if (!ptzr->ti.pixel_cropping_specified && ((t->v_pcleft > 0)  || (t->v_pctop > 0) || (t->v_pcright > 0) || (t->v_pcbottom > 0)))
-      ptzr->set_video_pixel_cropping(t->v_pcleft, t->v_pctop, t->v_pcright, t->v_pcbottom);
-    if (STEREO_MODE_UNSPECIFIED == ptzr->ti.stereo_mode)
-      ptzr->set_stereo_mode(t->v_stereo_mode);
+
+    t->handle_packetizer_display_dimensions();
+    t->handle_packetizer_pixel_cropping();
+    t->handle_packetizer_stereo_mode();
+
     if (CUE_STRATEGY_UNSPECIFIED == ptzr->get_cue_creation())
       ptzr->set_cue_creation(CUE_STRATEGY_IFRAMES);
 
@@ -1322,18 +1342,11 @@ kax_reader_c::create_video_packetizer(kax_track_t *t,
       t->ptzr = add_packetizer(new video_packetizer_c(this, nti, t->codec_id.c_str(), t->v_frate, t->v_width, t->v_height));
     }
 
-    if (!PTZR(t->ptzr)->ti.aspect_ratio_given) {
-      // The user hasn't set it.
-      if (0 != t->v_dwidth)
-        PTZR(t->ptzr)->set_video_display_width(t->v_dwidth);
-      if (0 != t->v_dheight)
-        PTZR(t->ptzr)->set_video_display_height(t->v_dheight);
-    }
+    t->ptzr_ptr = PTZR(t->ptzr);
 
-    if (!PTZR(t->ptzr)->ti.pixel_cropping_specified && ((t->v_pcleft > 0) || (t->v_pctop > 0) || (t->v_pcright > 0) || (t->v_pcbottom > 0)))
-      PTZR(t->ptzr)->set_video_pixel_cropping(t->v_pcleft, t->v_pctop, t->v_pcright, t->v_pcbottom);
-    if (STEREO_MODE_UNSPECIFIED == PTZR(t->ptzr)->ti.stereo_mode)
-      PTZR(t->ptzr)->set_stereo_mode(t->v_stereo_mode);
+    t->handle_packetizer_display_dimensions();
+    t->handle_packetizer_pixel_cropping();
+    t->handle_packetizer_stereo_mode();
 
   } else
     init_passthrough_packetizer(t);
