@@ -11,28 +11,28 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/os.h"
 
-#include <algorithm>
-#include <memory>
-
-#include "ac3_common.h"
-#include "common.h"
-#include "error.h"
-#include "M2VParser.h"
-#include "mp3_common.h"
-#include "mpeg4_common.h"
-#include "output_control.h"
-#include "p_ac3.h"
-#include "p_avc.h"
-#include "p_dts.h"
-#include "p_mp3.h"
-#include "p_truehd.h"
-#include "p_vc1.h"
-#include "p_video.h"
-#include "r_mpeg_ps.h"
-#include "smart_pointers.h"
-#include "truehd_common.h"
+#include "common/ac3.h"
+#include "common/common.h"
+#include "common/endian.h"
+#include "common/error.h"
+#include "common/math.h"
+#include "common/mp3.h"
+#include "common/mpeg1_2.h"
+#include "common/mpeg4_p2.h"
+#include "common/smart_pointers.h"
+#include "common/truehd.h"
+#include "input/r_mpeg_ps.h"
+#include "merge/output_control.h"
+#include "mpegparser/M2VParser.h"
+#include "output/p_ac3.h"
+#include "output/p_avc.h"
+#include "output/p_dts.h"
+#include "output/p_mp3.h"
+#include "output/p_mpeg1_2.h"
+#include "output/p_truehd.h"
+#include "output/p_vc1.h"
 
 #define PS_PROBE_SIZE 10 * 1024 * 1024
 
@@ -47,7 +47,7 @@ mpeg_ps_reader_c::probe_file(mm_io_c *io,
                              int64_t size) {
   try {
     memory_c af_buf((unsigned char *)safemalloc(PS_PROBE_SIZE), 0, true);
-    unsigned char *buf = af_buf.get();
+    unsigned char *buf = af_buf.get_buffer();
     int num_read;
 
     io->setFilePointer(0, seek_beginning);
@@ -340,12 +340,30 @@ mpeg_ps_reader_c::parse_packet(mpeg_ps_id_t &id,
 
   if (   (0xbc > id.id)
       || ((0xf0 <= id.id) && (0xfd != id.id))
-      || (0xbe == id.id)           // padding stream
       || (0xbf == id.id)) {        // private 2 stream
     io->skip(length);
     return false;
   }
 
+  if (0xbe == id.id) {        // padding stream
+    int64_t pos = io->getFilePointer();
+    io->skip(length);
+    uint32_t header = io->read_uint32_be();
+    if ( mpeg_is_start_code(header) ) {
+      io->setFilePointer(pos + length);
+    } else {
+      mxverb(2, boost::format("mpeg_ps: [begin] padding stream length incorrect at %1%, find next header...\n") % (pos - 6));
+      io->setFilePointer(pos);
+      header = 0xffffffff;
+      if (resync_stream(header)) {
+        full_length = io->getFilePointer() - pos - 4;
+        mxverb(2, boost::format("mpeg_ps: [end] padding stream length adjusted from %1% to %2%\n") % length % full_length);
+        io->setFilePointer(pos + full_length);
+      }
+    }
+    return false;
+  }
+
   if (0 == length)
     return false;
 
@@ -396,10 +414,10 @@ mpeg_ps_reader_c::parse_packet(mpeg_ps_id_t &id,
     length -= hdrlen;
 
     memory_c af_header(safemalloc(hdrlen), hdrlen, true);
-    if (io->read(af_header.get(), hdrlen) != hdrlen)
+    if (io->read(af_header.get_buffer(), hdrlen) != hdrlen)
       return false;
 
-    bit_cursor_c bc(af_header.get(), hdrlen);
+    bit_cursor_c bc(af_header.get_buffer(), hdrlen);
 
     try {
       // PTS
@@ -458,13 +476,10 @@ mpeg_ps_reader_c::parse_packet(mpeg_ps_id_t &id,
 
       } else if (   ((0x80 <= id.sub_id) && (0x8f >= id.sub_id))
                  || ((0x98 <= id.sub_id) && (0xcf >= id.sub_id))) {
-        io->skip(3);         // number of frames, startpos
-        length -= 3;
-
-        if ((0xa0 == (id.sub_id & 0xe0)) && (3 <= length)) { // LPCM
-          io->skip(3);
-          length -= 3;
-        }
+        // Number of frames, startpos. MLP/TrueHD audio has a 4 byte header.
+        int audio_header_len = (0xb0 <= id.sub_id) && (0xbf >= id.sub_id) ? 4 : 3;
+        io->skip(audio_header_len);
+        length -= audio_header_len;
       }
     }
 
@@ -571,10 +586,10 @@ mpeg_ps_reader_c::new_stream_v_avc_or_mpeg_1_2(mpeg_ps_id_t id,
         continue;
 
       memory_cptr new_buf = memory_c::alloc(new_length);
-      if (io->read(new_buf->get(), new_length) != new_length)
+      if (io->read(new_buf->get_buffer(), new_length) != new_length)
         throw false;
 
-      buffer.add(new_buf->get(), new_length);
+      buffer.add(new_buf->get_buffer(), new_length);
     }
   } catch (...) {
   }
@@ -588,7 +603,7 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
                                         unsigned char *buf,
                                         int length,
                                         mpeg_ps_track_ptr &track) {
-  auto_ptr<M2VParser> m2v_parser(new M2VParser);
+  counted_ptr<M2VParser> m2v_parser(new M2VParser);
 
   m2v_parser->WriteData(buf, length);
 
@@ -603,10 +618,10 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
       break;
 
     memory_c new_buf((unsigned char *)safemalloc(length), 0, true);
-    if (io->read(new_buf.get(), length) != length)
+    if (io->read(new_buf.get_buffer(), length) != length)
       break;
 
-    m2v_parser->WriteData(new_buf.get(), length);
+    m2v_parser->WriteData(new_buf.get_buffer(), length);
 
     state = m2v_parser->GetState();
   }
@@ -618,8 +633,8 @@ mpeg_ps_reader_c::new_stream_v_mpeg_1_2(mpeg_ps_id_t id,
   }
 
   MPEG2SequenceHeader seq_hdr = m2v_parser->GetSequenceHeader();
-  auto_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
-  if (frame.get() == NULL)
+  counted_ptr<MPEGFrame> frame(m2v_parser->ReadFrame());
+  if (!frame.is_set())
     throw false;
 
   track->fourcc         = FOURCC('M', 'P', 'G', '0' + m2v_parser->GetMPEGVersion());
@@ -668,10 +683,10 @@ mpeg_ps_reader_c::new_stream_v_avc(mpeg_ps_id_t id,
     if (!parse_packet(id, timecode, length, full_length))
       break;
     memory_c new_buf((unsigned char *)safemalloc(length), 0, true);
-    if (io->read(new_buf.get(), length) != length)
+    if (io->read(new_buf.get_buffer(), length) != length)
       break;
 
-    parser.add_bytes(new_buf.get(), length);
+    parser.add_bytes(new_buf.get_buffer(), length);
   }
 
   if (!parser.headers_parsed())
@@ -680,7 +695,7 @@ mpeg_ps_reader_c::new_stream_v_avc(mpeg_ps_id_t id,
   track->v_avcc = parser.get_avcc();
 
   try {
-    mm_mem_io_c avcc(track->v_avcc->get(), track->v_avcc->get_size());
+    mm_mem_io_c avcc(track->v_avcc->get_buffer(), track->v_avcc->get_size());
     mm_mem_io_c new_avcc(NULL, track->v_avcc->get_size(), 1024);
     memory_cptr nalu(new memory_c());
     int num_sps, sps, sps_length;
@@ -702,7 +717,7 @@ mpeg_ps_reader_c::new_stream_v_avc(mpeg_ps_id_t id,
       avcc.read(nalu, sps_length);
 
       abort = false;
-      if ((0 < sps_length) && ((nalu->get()[0] & 0x1f) == 7)) {
+      if ((0 < sps_length) && ((nalu->get_buffer()[0] & 0x1f) == 7)) {
         nalu_to_rbsp(nalu);
         if (!mpeg4::p10::parse_sps(nalu, sps_info, true))
           throw false;
@@ -765,10 +780,10 @@ mpeg_ps_reader_c::new_stream_v_vc1(mpeg_ps_id_t id,
       break;
 
     memory_cptr new_buf = memory_c::alloc(length);
-    if (io->read(new_buf->get(), length) != length)
+    if (io->read(new_buf->get_buffer(), length) != length)
       break;
 
-    parser.add_bytes(new_buf->get(), length);
+    parser.add_bytes(new_buf->get_buffer(), length);
   }
 
   if (!parser.is_sequence_header_available())
@@ -843,10 +858,10 @@ mpeg_ps_reader_c::new_stream_a_dts(mpeg_ps_id_t id,
       continue;
 
     memory_cptr new_buf = memory_c::alloc(length);
-    if (io->read(new_buf->get(), length) != length)
+    if (io->read(new_buf->get_buffer(), length) != length)
       throw false;
 
-    buffer.add(new_buf->get(), length);
+    buffer.add(new_buf->get_buffer(), length);
   }
 }
 
@@ -891,10 +906,10 @@ mpeg_ps_reader_c::new_stream_a_truehd(mpeg_ps_id_t id,
       continue;
 
     memory_cptr new_buf = memory_c::alloc(length);
-    if (io->read(new_buf->get(), length) != length)
+    if (io->read(new_buf->get_buffer(), length) != length)
       throw false;
 
-    parser.add_data(new_buf->get(), length);
+    parser.add_data(new_buf->get_buffer(), length);
   }
 }
 
@@ -988,7 +1003,7 @@ mpeg_ps_reader_c::found_new_stream(mpeg_ps_id_t id) {
       return;
 
     memory_c af_buf((unsigned char *)safemalloc(length), 0, true);
-    unsigned char *buf = af_buf.get();
+    unsigned char *buf = af_buf.get_buffer();
     if (io->read(buf, length) != length)
       throw false;
 
@@ -1235,7 +1250,9 @@ mpeg_ps_reader_c::read(generic_packetizer_c *,
     while (find_next_packet(new_id)) {
       packet_pos = io->getFilePointer() - 4;
       if (!parse_packet(new_id, timecode, length, full_length)) {
-        mxverb(2, boost::format("mpeg_ps: packet_parse failed at %1%, skipping %2%\n") % packet_pos % full_length);
+        if (    (0xbe != new_id.id)       // padding stream
+             && (0xbf != new_id.id))      // private 2 stream (navigation data)
+          mxverb(2, boost::format("mpeg_ps: parse_packet failed at %1%, skipping %2%\n") % packet_pos % full_length);
         io->setFilePointer(packet_pos + 4 + 2 + full_length);
         continue;
       }
@@ -1245,7 +1262,7 @@ mpeg_ps_reader_c::read(generic_packetizer_c *,
         continue;
       }
 
-      mpeg_ps_track_t *track = tracks[id2idx[new_id.idx()]].get();
+      mpeg_ps_track_t *track = tracks[id2idx[new_id.idx()]].get_object();
 
       mxverb(3,
              boost::format("mpeg_ps: packet for 0x%|1$02x|(%|2$02x|) length %3% at %4% timecode %5%\n")
@@ -1312,7 +1329,7 @@ mpeg_ps_reader_c::finish() {
   if (file_done)
     return FILE_STATUS_DONE;
 
-  vector<mpeg_ps_track_ptr>::iterator track;
+  std::vector<mpeg_ps_track_ptr>::iterator track;
 
   mxforeach(track, tracks) {
     if (0 < (*track)->buffer_usage) {
@@ -1334,7 +1351,7 @@ mpeg_ps_reader_c::get_progress() {
 
 void
 mpeg_ps_reader_c::identify() {
-  vector<string> verbose_info;
+  std::vector<std::string> verbose_info;
   int i;
 
   id_result_container((boost::format("MPEG %1% program stream (PS)") % version).str());
