@@ -15,33 +15,39 @@
      the original authors.
 */
 
-#include "os.h"
+#include "common/os.h"
 
 #include <algorithm>
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstring>
 #if defined(HAVE_ZLIB_H)
 #include <zlib.h>
 #endif
 
-#include "aac_common.h"
+extern "C" {
 #include "avilib.h"
-#include "common.h"
-#include "hacks.h"
-#include "iso639.h"
-#include "matroska.h"
-#include "output_control.h"
-#include "p_aac.h"
-#include "p_ac3.h"
-#include "p_mp3.h"
-#include "p_passthrough.h"
-#include "p_pcm.h"
-#include "p_video.h"
-#include "r_qtmp4.h"
+}
+
+#include "common/aac.h"
+#include "common/chapters/chapters.h"
+#include "common/common.h"
+#include "common/endian.h"
+#include "common/hacks.h"
+#include "common/iso639.h"
+#include "common/locale.h"
+#include "common/matroska.h"
+#include "common/strings/formatting.h"
+#include "input/r_qtmp4.h"
+#include "merge/output_control.h"
+#include "output/p_aac.h"
+#include "output/p_ac3.h"
+#include "output/p_mp3.h"
+#include "output/p_mpeg1_2.h"
+#include "output/p_mpeg4_p2.h"
+#include "output/p_mpeg4_p10.h"
+#include "output/p_passthrough.h"
+#include "output/p_pcm.h"
+#include "output/p_video.h"
 
-using namespace std;
 using namespace libmatroska;
 
 #if defined(ARCH_BIGENDIAN)
@@ -64,7 +70,7 @@ space(int num) {
   memset(s, ' ', num);
   s[num] = 0;
 
-  return string(s);
+  return std::string(s);
 }
 
 int
@@ -224,14 +230,17 @@ qtmp4_reader_c::parse_headers() {
          && strncasecmp(dmx->fourcc, "cvid", 4)
          && strncasecmp(dmx->fourcc, "rle ", 4)
          && strncasecmp(dmx->fourcc, "mp4v", 4)
+         && strncasecmp(dmx->fourcc, "xvid", 4)
          && strncasecmp(dmx->fourcc, "avc1", 4))
         ||
         (   ('a' == dmx->type)
          && strncasecmp(dmx->fourcc, "QDM", 3)
          && strncasecmp(dmx->fourcc, "MP4A", 4)
+         && strncasecmp(dmx->fourcc, ".mp3", 4)
          && strncasecmp(dmx->fourcc, "twos", 4)
          && strncasecmp(dmx->fourcc, "sowt", 4)
-         && strncasecmp(dmx->fourcc, "ac-3", 4))) {
+         && strncasecmp(dmx->fourcc, "ac-3", 4)
+         && strncasecmp(dmx->fourcc, "sac3", 4))) {
       mxwarn(boost::format(Y("Quicktime/MP4 reader: Unknown/unsupported FourCC '%|1$.4s|' for track %2%.\n")) % dmx->fourcc % dmx->id);
       continue;
     }
@@ -314,7 +323,7 @@ qtmp4_reader_c::parse_headers() {
 
 void
 qtmp4_reader_c::calculate_timecodes() {
-  vector<qtmp4_demuxer_cptr>::iterator idmx;
+  std::vector<qtmp4_demuxer_cptr>::iterator idmx;
   int64_t min_timecode = 0;
 
   mxforeach(idmx, demuxers) {
@@ -348,7 +357,7 @@ qtmp4_reader_c::parse_video_header_priv_atoms(qtmp4_demuxer_cptr &dmx,
                                               unsigned char *mem,
                                               int size,
                                               int level) {
-  if (!dmx->v_is_avc && strncasecmp(dmx->fourcc, "mp4v", 4) && (0 != size)) {
+  if (!dmx->v_is_avc && strncasecmp(dmx->fourcc, "mp4v", 4) && strncasecmp(dmx->fourcc, "xvid", 4) && (0 != size)) {
     dmx->priv_size = size;
     dmx->priv      = (unsigned char *)safememdup(mem, size);
 
@@ -504,9 +513,9 @@ qtmp4_reader_c::handle_cmvd_atom(qt_atom_t atom,
   mm_io_c *old_io         = io;
   uint32_t cmov_size      = atom.size - atom.hsize;
   memory_cptr af_cmov_buf = memory_c::alloc(cmov_size);
-  unsigned char *cmov_buf = af_cmov_buf->get();
+  unsigned char *cmov_buf = af_cmov_buf->get_buffer();
   memory_cptr af_moov_buf = memory_c::alloc(moov_size + 16);
-  unsigned char *moov_buf = af_moov_buf->get();
+  unsigned char *moov_buf = af_moov_buf->get_buffer();
 
   if (io->read(cmov_buf, cmov_size) != cmov_size)
     throw error_c(Y("end-of-file"));
@@ -703,6 +712,9 @@ qtmp4_reader_c::handle_moov_atom(qt_atom_t parent,
     } else if (FOURCC('m', 'v', 'h', 'd') == atom.fourcc)
       handle_mvhd_atom(atom.to_parent(), level + 1);
 
+    else if (FOURCC('u', 'd', 't', 'a') == atom.fourcc)
+      handle_udta_atom(atom.to_parent(), level + 1);
+
     else if (FOURCC('t', 'r', 'a', 'k') == atom.fourcc) {
       qtmp4_demuxer_cptr new_dmx(new qtmp4_demuxer_c);
 
@@ -731,6 +743,80 @@ qtmp4_reader_c::handle_mvhd_atom(qt_atom_t atom,
   mxverb(2, boost::format("Quicktime/MP4 reader:%1%Time scale: %2%\n") % space(level * 2 + 1) % time_scale);
 }
 
+void
+qtmp4_reader_c::handle_udta_atom(qt_atom_t parent,
+                                 int level) {
+  while (8 <= parent.size) {
+    qt_atom_t atom = read_atom();
+    print_basic_atom_info();
+
+    if (FOURCC('c', 'h', 'p', 'l') == atom.fourcc)
+      handle_chpl_atom(atom.to_parent(), level + 1);
+
+    skip_atom();
+    parent.size -= atom.size;
+  }
+}
+
+void
+qtmp4_reader_c::handle_chpl_atom(qt_atom_t atom,
+                                 int level) {
+  if (ti.no_chapters || (NULL != chapters))
+    return;
+
+  io->skip(1 + 3 + 4);          // Version, flags, zero
+
+  int count = io->read_uint8();
+  mxverb(2, boost::format("Quicktime/MP4 reader:%1%Chapter list: %2% entries\n") % space(level * 2 + 1) % count);
+
+  if (0 == count)
+    return;
+
+  std::vector<qtmp4_chapter_entry_t> entries;
+
+  int i;
+  for (i = 0; i < count; ++i) {
+    uint64_t timecode = io->read_uint64_be() * 100;
+    memory_cptr buf   = memory_c::alloc(io->read_uint8() + 1);
+    memset(buf->get_buffer(), 0, buf->get_size());
+
+    if (io->read(buf->get_buffer(), buf->get_size() - 1) != (buf->get_size() - 1))
+      break;
+
+    entries.push_back(qtmp4_chapter_entry_t(std::string(reinterpret_cast<char *>(buf->get_buffer())), timecode));
+  }
+
+  if (entries.empty())
+    return;
+
+  recode_chapter_entries(entries);
+
+  stable_sort(entries.begin(), entries.end());
+
+  mm_mem_io_c out(NULL, 0, 1000);
+  out.set_file_name(ti.fname);
+  out.write_bom("UTF-8");
+
+  for (i = 0; entries.size() > i; ++i) {
+    qtmp4_chapter_entry_t &chapter = entries[i];
+
+    mxverb(3, boost::format("Quicktime/MP4 reader:%1%%2%: start %4% name %3%\n") % space((level + 1) * 2 + 1) % i % chapter.m_name % format_timecode(chapter.m_timecode));
+
+    out.puts(boost::format("CHAPTER%|1$02d|=%|2$02d|:%|3$02d|:%|4$02d|.%|5$03d|\n"
+                           "CHAPTER%|1$02d|NAME=%6%\n")
+             % count
+             % (int)( chapter.m_timecode / 60 / 60 / 1000000000)
+             % (int)((chapter.m_timecode      / 60 / 1000000000) %   60)
+             % (int)((chapter.m_timecode           / 1000000000) %   60)
+             % (int)((chapter.m_timecode           /    1000000) % 1000)
+             % chapter.m_name);
+  }
+
+  mm_text_io_c text_out(&out, false);
+  chapters = parse_chapters(&text_out, 0, -1, 0, ti.chapter_language);
+  align_chapter_edition_uids(chapters);
+}
+
 void
 qtmp4_reader_c::handle_stbl_atom(qtmp4_demuxer_cptr &new_dmx,
                                  qt_atom_t parent,
@@ -842,7 +928,7 @@ qtmp4_reader_c::handle_stsd_atom(qtmp4_demuxer_cptr &new_dmx,
       mxerror(boost::format(Y("Quicktime/MP4 reader: The 'size' field is too small in the stream description atom for track ID %1%.\n")) % new_dmx->id);
 
     memory_cptr af_priv = memory_c::alloc(size);
-    unsigned char *priv = af_priv->get();
+    unsigned char *priv = af_priv->get_buffer();
 
     put_uint32_be(priv, size);
     if (io->read(priv + sizeof(uint32_t), size - sizeof(uint32_t)) != (size - sizeof(uint32_t)))
@@ -855,13 +941,18 @@ qtmp4_reader_c::handle_stsd_atom(qtmp4_demuxer_cptr &new_dmx,
         mxerror(boost::format(Y("Quicktime/MP4 reader: Could not read the sound description atom for track ID %1%.\n")) % new_dmx->id);
 
       sound_v1_stsd_atom_t sv1_stsd;
+      sound_v2_stsd_atom_t sv2_stsd;
       memcpy(&sv1_stsd, priv, sizeof(sound_v0_stsd_atom_t));
+      memcpy(&sv2_stsd, priv, sizeof(sound_v0_stsd_atom_t));
+
       if (0 != new_dmx->fourcc[0])
         mxwarn(boost::format(Y("Quicktime/MP4 reader: Track ID %1% has more than one FourCC. Only using the first one (%|2$.4s|) and not this one (%|3$.4s|).\n"))
                % new_dmx->id % new_dmx->fourcc % (const unsigned char *)sv1_stsd.v0.base.fourcc);
       else
         memcpy(new_dmx->fourcc, sv1_stsd.v0.base.fourcc, 4);
 
+      uint16_t version = get_uint16_be(&sv1_stsd.v0.version);
+
       mxverb(2,
              boost::format("Quicktime/MP4 reader:%1%FourCC: %|2$.4s|, channels: %3%, sample size: %4%, compression id: %5%, sample rate: 0x%|6$08x|, version: %7%")
              % space(level * 2 + 1)
@@ -872,7 +963,7 @@ qtmp4_reader_c::handle_stsd_atom(qtmp4_demuxer_cptr &new_dmx,
              % get_uint32_be(&sv1_stsd.v0.sample_rate)
              % get_uint16_be(&sv1_stsd.v0.version));
 
-      if (get_uint16_be(&sv1_stsd.v0.version) == 1) {
+      if (1 == version) {
         if (sizeof(sound_v1_stsd_atom_t) > size)
           mxerror(boost::format(Y("Quicktime/MP4 reader: Could not read the extended sound description atom for track ID %1%.\n")) % new_dmx->id);
 
@@ -884,7 +975,25 @@ qtmp4_reader_c::handle_stsd_atom(qtmp4_demuxer_cptr &new_dmx,
                % get_uint32_be(&sv1_stsd.v1.bytes_per_packet)
                % get_uint32_be(&sv1_stsd.v1.bytes_per_frame)
                % get_uint32_be(&sv1_stsd.v1.bytes_per_sample));
+
+      } else if (2 == version) {
+        if (sizeof(sound_v2_stsd_atom_t) > size)
+          mxerror(boost::format(Y("Quicktime/MP4 reader: Could not read the extended sound description atom for track ID %1%.\n")) % new_dmx->id);
+
+        memcpy(&sv2_stsd, priv, sizeof(sound_v2_stsd_atom_t));
+
+        mxverb(2,
+               boost::format(" struct size: %1% sample rate: %|2$016x| channels: %3% const1: 0x%|4$08x| bits per channel: %5% flags: %6% bytes per frame: %7% samples per frame: %8%")
+               % get_uint32_be(&sv2_stsd.v2.v2_struct_size)
+               % get_uint64_be(&sv2_stsd.v2.sample_rate)
+               % get_uint32_be(&sv2_stsd.v2.channels)
+               % get_uint32_be(&sv2_stsd.v2.const1)
+               % get_uint32_be(&sv2_stsd.v2.bits_per_channel)
+               % get_uint32_be(&sv2_stsd.v2.flags)
+               % get_uint32_be(&sv2_stsd.v2.bytes_per_frame)
+               % get_uint32_be(&sv2_stsd.v2.samples_per_frame));
       }
+
       mxverb(2, "\n");
 
       new_dmx->a_channels   = get_uint16_be(&sv1_stsd.v0.channels);
@@ -899,7 +1008,7 @@ qtmp4_reader_c::handle_stsd_atom(qtmp4_demuxer_cptr &new_dmx,
         stsd_size = sizeof(sound_v1_stsd_atom_t);
 
       else if (get_uint16_be(&sv1_stsd.v0.version) == 2)
-        stsd_size = 72;
+        stsd_size = sizeof(sound_v2_stsd_atom_t);
 
     } else if ('v' == new_dmx->type) {
       new_dmx->v_stsd = clone_memory(priv, size);
@@ -1058,7 +1167,7 @@ qtmp4_reader_c::handle_elst_atom(qtmp4_demuxer_cptr &new_dmx,
     editlist.speed    = io->read_uint32_be();
   }
 
-  mxverb(2, boost::format("Quicktime/MP4 reader:%1%Edit list table: %2% entries\n") % space(level * 2 + 1) % count);
+  mxverb(2, boost::format("Quicktime/MP4 reader:%1%Edit std::list table: %2% entries\n") % space(level * 2 + 1) % count);
   for (i = 0; i < count; ++i)
     mxverb(4,
            boost::format("Quicktime/MP4 reader:%1%%2%: duration %3% pos %4% speed %5%\n")
@@ -1136,7 +1245,11 @@ qtmp4_reader_c::read(generic_packetizer_c *ptzr,
   int buffer_offset = 0;
   unsigned char *buffer;
 
-  if (('v' == dmx->type) && (0 == dmx->pos) && !strncasecmp(dmx->fourcc, "mp4v", 4) && dmx->esds_parsed && (NULL != dmx->esds.decoder_config)) {
+  if (   ('v' == dmx->type)
+      && (0 == dmx->pos)
+      && (!strncasecmp(dmx->fourcc, "mp4v", 4) || !strncasecmp(dmx->fourcc, "xvid", 4))
+      && dmx->esds_parsed
+      && (NULL != dmx->esds.decoder_config)) {
     buffer        = (unsigned char *)safemalloc(index.size + dmx->esds.decoder_config_len);
     buffer_offset = dmx->esds.decoder_config_len;
 
@@ -1270,7 +1383,7 @@ qtmp4_reader_c::create_bitmap_info_header(qtmp4_demuxer_cptr &dmx,
                                           const void *extra_data) {
   int full_size           = sizeof(alBITMAPINFOHEADER) + extra_size;
   memory_cptr bih_p       = memory_c::alloc(full_size);
-  alBITMAPINFOHEADER *bih = (alBITMAPINFOHEADER *)bih_p->get();
+  alBITMAPINFOHEADER *bih = (alBITMAPINFOHEADER *)bih_p->get_buffer();
 
   memset(bih, 0, full_size);
   put_uint32_le(&bih->bi_size,       full_size);
@@ -1291,7 +1404,7 @@ bool
 qtmp4_reader_c::create_audio_packetizer_ac3(qtmp4_demuxer_cptr &dmx) {
   memory_cptr buf = memory_c::alloc(64);
 
-  if (!dmx->read_first_bytes(buf, 64, io) || (-1 == find_ac3_header(buf->get(), buf->get_size(), &dmx->m_ac3_header, false))) {
+  if (!dmx->read_first_bytes(buf, 64, io) || (-1 == find_ac3_header(buf->get_buffer(), buf->get_size(), &dmx->m_ac3_header, false))) {
     mxwarn_tid(ti.fname, dmx->id, Y("No AC3 header found in first frame; track will be skipped.\n"));
     dmx->ok = false;
 
@@ -1309,7 +1422,7 @@ qtmp4_reader_c::create_video_packetizer_svq1(qtmp4_demuxer_cptr &dmx) {
   memory_cptr bih(create_bitmap_info_header(dmx, "SVQ1"));
 
   ti.private_size = bih->get_size();
-  ti.private_data = (unsigned char *)bih->get();
+  ti.private_data = (unsigned char *)bih->get_buffer();
 
   dmx->ptzr       = add_packetizer(new video_packetizer_c(this, ti, MKV_V_MSCOMP, 0.0, dmx->v_width, dmx->v_height));
   ti.private_data = NULL;
@@ -1322,7 +1435,7 @@ qtmp4_reader_c::create_video_packetizer_mpeg4_p2(qtmp4_demuxer_cptr &dmx) {
   memory_cptr bih(create_bitmap_info_header(dmx, "DIVX"));
 
   ti.private_size = bih->get_size();
-  ti.private_data = (unsigned char *)bih->get();
+  ti.private_data = (unsigned char *)bih->get_buffer();
   dmx->ptzr       = add_packetizer(new mpeg4_p2_video_packetizer_c(this, ti, 0.0, dmx->v_width, dmx->v_height, false));
   ti.private_data = NULL;
 
@@ -1358,7 +1471,7 @@ qtmp4_reader_c::create_video_packetizer_mpeg4_p10(qtmp4_demuxer_cptr &dmx) {
 void
 qtmp4_reader_c::create_video_packetizer_standard(qtmp4_demuxer_cptr &dmx) {
   ti.private_size = dmx->v_stsd->get_size();
-  ti.private_data = dmx->v_stsd->get();
+  ti.private_data = dmx->v_stsd->get_buffer();
   dmx->ptzr       = add_packetizer(new video_packetizer_c(this, ti, MKV_V_QUICKTIME, 0.0, dmx->v_width, dmx->v_height));
   ti.private_data = NULL;
 
@@ -1398,7 +1511,7 @@ qtmp4_reader_c::create_audio_packetizer_passthrough(qtmp4_demuxer_cptr &dmx) {
 
   ptzr->set_track_type(track_audio);
   ptzr->set_codec_id(MKV_A_QUICKTIME);
-  ptzr->set_codec_private(dmx->a_stsd->get(), dmx->a_stsd->get_size());
+  ptzr->set_codec_private(dmx->a_stsd->get_buffer(), dmx->a_stsd->get_size());
   ptzr->set_audio_sampling_freq(dmx->a_samplerate);
   ptzr->set_audio_channels(dmx->a_channels);
 
@@ -1416,7 +1529,7 @@ qtmp4_reader_c::create_packetizer(int64_t tid) {
       break;
     }
 
-  if (!dmx.get() || !dmx->ok || !demuxing_requested(dmx->type, dmx->id) || (-1 != dmx->ptzr))
+  if (!dmx.is_set() || !dmx->ok || !demuxing_requested(dmx->type, dmx->id) || (-1 != dmx->ptzr))
     return;
 
   ti.id              = dmx->id;
@@ -1425,7 +1538,7 @@ qtmp4_reader_c::create_packetizer(int64_t tid) {
   bool packetizer_ok = true;
 
   if ('v' == dmx->type) {
-    if (!strncasecmp(dmx->fourcc, "mp4v", 4))
+    if (!strncasecmp(dmx->fourcc, "mp4v", 4) || !strncasecmp(dmx->fourcc, "xvid", 4))
       create_video_packetizer_mpeg4_p2(dmx);
 
     else if (!strncasecmp(dmx->fourcc, "mpg1", 4) || !strncasecmp(dmx->fourcc, "mpg2", 4))
@@ -1448,10 +1561,13 @@ qtmp4_reader_c::create_packetizer(int64_t tid) {
     else if (!strncasecmp(dmx->fourcc, "MP4A", 4) && ((MP4OTI_MPEG2AudioPart3 == dmx->esds.object_type_id) || (MP4OTI_MPEG1Audio == dmx->esds.object_type_id)))
       create_audio_packetizer_mp3(dmx);
 
+    else if (!strncasecmp(dmx->fourcc, ".mp3", 4))
+      create_audio_packetizer_mp3(dmx);
+
     else if (!strncasecmp(dmx->fourcc, "twos", 4) || !strncasecmp(dmx->fourcc, "sowt", 4))
       create_audio_packetizer_pcm(dmx);
 
-    else if (!strncasecmp(dmx->fourcc, "ac-3", 4))
+    else if (!strncasecmp(dmx->fourcc, "ac-3", 4) || !strncasecmp(dmx->fourcc, "sac3", 4))
       packetizer_ok = create_audio_packetizer_ac3(dmx);
 
     else
@@ -1482,7 +1598,7 @@ qtmp4_reader_c::get_progress() {
 
 void
 qtmp4_reader_c::identify() {
-  vector<string> verbose_info;
+  std::vector<std::string> verbose_info;
   unsigned int i;
 
   id_result_container("Quicktime/MP4");
@@ -1501,6 +1617,9 @@ qtmp4_reader_c::identify() {
     id_result_track(dmx->id, dmx->type == 'v' ? ID_RESULT_TRACK_VIDEO : dmx->type == 'a' ? ID_RESULT_TRACK_AUDIO : ID_RESULT_TRACK_UNKNOWN,
                     (boost::format("%|1$.4s|") %  dmx->fourcc).str(), verbose_info);
   }
+
+  if (NULL != chapters)
+    id_result_chapters(count_chapter_atoms(*chapters));
 }
 
 void
@@ -1527,6 +1646,23 @@ qtmp4_reader_c::decode_and_verify_language(uint16_t coded_language) {
   return "";
 }
 
+void
+qtmp4_reader_c::recode_chapter_entries(std::vector<qtmp4_chapter_entry_t> &entries) {
+  int i;
+
+  if (g_identifying) {
+    for (i = 0; entries.size() > i; ++i)
+      entries[i].m_name = empty_string;
+    return;
+  }
+
+  std::string charset              = ti.chapter_charset.empty() ? "UTF-8" : ti.chapter_charset;
+  charset_converter_cptr converter = charset_converter_c::init(ti.chapter_charset);
+
+  for (i = 0; entries.size() > i; ++i)
+    entries[i].m_name = converter->utf8(entries[i].m_name);
+}
+
 // ----------------------------------------------------------------------
 
 void
@@ -1539,7 +1675,7 @@ qtmp4_demuxer_c::calculate_fps() {
     mxverb(3, boost::format("Quicktime/MP4 reader: calculate_fps: case 1: %1%\n") % fps);
 
   } else {
-    map<int64_t, int> duration_map;
+    std::map<int64_t, int> duration_map;
 
     for (int i = 0; sample_table.size() > (i + 1); ++i) {
       int64_t this_duration = sample_table[i + 1].pts - sample_table[i].pts;
@@ -1549,8 +1685,8 @@ qtmp4_demuxer_c::calculate_fps() {
       ++duration_map[this_duration];
     }
 
-    map<int64_t, int>::const_iterator most_common = duration_map.begin();
-    map<int64_t, int>::const_iterator it;
+    std::map<int64_t, int>::const_iterator most_common = duration_map.begin();
+    std::map<int64_t, int>::const_iterator it;
     mxforeach(it, duration_map)
       if (it->second > most_common->second)
         most_common = it;
@@ -1595,7 +1731,7 @@ qtmp4_demuxer_c::calculate_timecodes() {
   }
 
   int64_t v_dts_offset = 0;
-  vector<int64_t> timecodes_before_offsets;
+  std::vector<int64_t> timecodes_before_offsets;
 
   if (('v' == type) && v_is_avc && !frame_offset_table.empty())
     v_dts_offset = to_nsecs(frame_offset_table[0]);
@@ -1787,7 +1923,7 @@ qtmp4_demuxer_c::update_editlist_table(int64_t global_time_scale) {
   if (('v' == type) && v_is_avc && !frame_offset_table.empty() && (frame_offset_table[0] <= min_editlist_pts))
     pts_offset = frame_offset_table[0];
 
-  mxverb(4, boost::format("qtmp4: Updating edit list table for track %1%; pts_offset = %2%\n") % id % pts_offset);
+  mxverb(4, boost::format("qtmp4: Updating edit std::list table for track %1%; pts_offset = %2%\n") % id % pts_offset);
 
   for (i = 0; editlist_table.size() > i; ++i) {
     qt_editlist_t &el = editlist_table[i];
@@ -1851,7 +1987,7 @@ qtmp4_demuxer_c::build_index_constant_sample_size_mode() {
       frame_size = chunk_table[frame_idx].size;
 
       if ('a' == type) {
-        sound_v1_stsd_atom_t *sound_stsd_atom = (sound_v1_stsd_atom_t *)a_stsd->get();
+        sound_v1_stsd_atom_t *sound_stsd_atom = (sound_v1_stsd_atom_t *)a_stsd->get_buffer();
         if (get_uint16_be(&sound_stsd_atom->v0.version) == 1) {
           frame_size *= get_uint32_be(&sound_stsd_atom->v1.bytes_per_frame);
           frame_size /= get_uint32_be(&sound_stsd_atom->v1.samples_per_packet);
@@ -1905,7 +2041,7 @@ qtmp4_demuxer_c::read_first_bytes(memory_cptr &buf,
     int num_bytes_to_read = std::min((int64_t)num_bytes, index.size);
 
     io->setFilePointer(index.file_pos);
-    if (io->read(buf->get() + buf_pos, num_bytes_to_read) < num_bytes_to_read)
+    if (io->read(buf->get_buffer() + buf_pos, num_bytes_to_read) < num_bytes_to_read)
       return false;
 
     num_bytes -= num_bytes_to_read;
