@@ -734,9 +734,10 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
     return;
 
   if ((dmx->width != width) || (dmx->height != height)) {
-    uint32_t disp_width, disp_height;
+    uint32_t disp_width  = 0;
+    uint32_t disp_height = 0;
 
-    if (!ti.aspect_ratio_given && !ti.display_dimensions_given) {
+    if (!ti.display_dimensions_or_aspect_ratio_set()) {
       disp_width  = dmx->width;
       disp_height = dmx->height;
 
@@ -750,7 +751,7 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
       dmx->width  = width;
       dmx->height = height;
 
-    } else {                  // ti.aspect_ratio_given == true
+    } else if (ti.aspect_ratio_given) {
       dmx->width  = width;
       dmx->height = height;
 
@@ -768,11 +769,13 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
     KaxTrackEntry *track_entry = PTZR(dmx->ptzr)->get_track_entry();
     KaxTrackVideo &video       = GetChild<KaxTrackVideo>(*track_entry);
 
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelWidth>(video)))    = width;
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelHeight>(video)))   = height;
+    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelWidth>(video)))      = width;
+    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelHeight>(video)))     = height;
 
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayWidth>(video)))  = disp_width;
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayHeight>(video))) = disp_height;
+    if ((0 != disp_width) && (0 != disp_height)) {
+      *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayWidth>(video)))  = disp_width;
+      *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayHeight>(video))) = disp_height;
+    }
 
     rerender_track_headers();
   }
