@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_real.h 3395 2006-12-30 12:56:33Z mosu $
-
    class definitions for the RealMedia demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,17 +14,17 @@
 #ifndef __R_REAL_H
 #define __R_REAL_H
 
-#include "os.h"
+#include "common/os.h"
 
 #include <stdio.h>
 
 #include <vector>
 
-#include "common.h"
-#include "error.h"
-#include "librmff.h"
-#include "p_video.h"
-#include "pr_generic.h"
+#include "common/common.h"
+#include "common/error.h"
+#include "librmff/librmff.h"
+#include "output/p_video.h"
+#include "merge/pr_generic.h"
 
 typedef struct {
   memory_cptr data;
@@ -59,20 +57,34 @@ struct real_demuxer_t {
   int num_packets;
   int64_t last_timecode, ref_timecode;
 
-  vector<rv_segment_cptr> segments;
+  std::vector<rv_segment_cptr> segments;
 
   real_demuxer_t(rmff_track_t *n_track):
-    ptzr(-1), track(n_track),
-    bsid(0), channels(0), samples_per_second(0), bits_per_sample(0),
-    width(0), height(0),
-    is_aac(false), rv_dimensions(false),
-    force_keyframe_flag(false), cook_audio_fix(false),
+    ptzr(-1),
+    track(n_track),
+    bsid(0),
+    channels(0),
+    samples_per_second(0),
+    bits_per_sample(0),
+    width(0),
+    height(0),
+    is_aac(false),
+    rv_dimensions(false),
+    force_keyframe_flag(false),
+    cook_audio_fix(false),
     fps(0.0),
-    rvp(NULL), ra4p(NULL), ra5p(NULL),
-    private_data(NULL), extra_data(NULL),
-    private_size(0), extra_data_size(0),
-    first_frame(true), num_packets(0),
-    last_timecode(0), ref_timecode(0) {
+    rvp(NULL),
+    ra4p(NULL),
+    ra5p(NULL),
+    private_data(NULL),
+    extra_data(NULL),
+    private_size(0),
+    extra_data_size(0),
+    first_frame(true),
+    num_packets(0),
+    last_timecode(0),
+    ref_timecode(0) {
+
     memset(fourcc, 0, 5);
   };
 };
@@ -82,7 +94,7 @@ typedef counted_ptr<real_demuxer_t> real_demuxer_cptr;
 class real_reader_c: public generic_reader_c {
 private:
   rmff_file_t *file;
-  vector<counted_ptr<real_demuxer_t> > demuxers;
+  std::vector<counted_ptr<real_demuxer_t> > demuxers;
   int64_t file_size;
   bool done;
 
@@ -102,20 +114,20 @@ public:
 protected:
   virtual void parse_headers();
   virtual real_demuxer_cptr find_demuxer(int id);
-  virtual void assemble_video_packet(real_demuxer_cptr dmx,
-                                     rmff_frame_t *frame);
+  virtual void assemble_video_packet(real_demuxer_cptr dmx, rmff_frame_t *frame);
   virtual file_status_e finish();
-  virtual bool get_rv_dimensions(unsigned char *buf, int size, uint32_t &width,
-                                 uint32_t &height);
-  virtual void set_dimensions(real_demuxer_cptr dmx, unsigned char *buffer,
-                              int size);
+  virtual bool get_rv_dimensions(unsigned char *buf, int size, uint32_t &width, uint32_t &height);
+  virtual void set_dimensions(real_demuxer_cptr dmx, unsigned char *buffer, int size);
   virtual void get_information_from_data();
   virtual void deliver_aac_frames(real_demuxer_cptr dmx, memory_c &mem);
-  virtual void queue_audio_frames(real_demuxer_cptr dmx, memory_c &mem,
-                                  uint64_t timecode, uint32_t flags);
-  virtual void queue_one_audio_frame(real_demuxer_cptr dmx, memory_c &mem,
-                                     uint64_t timecode, uint32_t flags);
+  virtual void queue_audio_frames(real_demuxer_cptr dmx, memory_c &mem, uint64_t timecode, uint32_t flags);
+  virtual void queue_one_audio_frame(real_demuxer_cptr dmx, memory_c &mem, uint64_t timecode, uint32_t flags);
   virtual void deliver_audio_frames(real_demuxer_cptr dmx, uint64_t duration);
+
+  virtual void create_audio_packetizer(real_demuxer_cptr dmx);
+  virtual void create_aac_audio_packetizer(real_demuxer_cptr dmx);
+  virtual void create_dnet_audio_packetizer(real_demuxer_cptr dmx);
+  virtual void create_video_packetizer(real_demuxer_cptr dmx);
 };
 
 #endif  // __R_REAL_H
