@@ -14,22 +14,22 @@
 #ifndef __R_TTA_H
 #define __R_TTA_H
 
-#include "os.h"
+#include "common/os.h"
 
 #include <stdio.h>
 
-#include "common.h"
-#include "error.h"
-#include "mm_io.h"
-#include "pr_generic.h"
-#include "tta_common.h"
+#include "common/common.h"
+#include "common/error.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
+#include "common/tta.h"
 
 class tta_reader_c: public generic_reader_c {
 private:
   unsigned char *chunk;
   mm_io_c *io;
   int64_t bytes_processed, size;
-  vector<uint32_t> seek_points;
+  std::vector<uint32_t> seek_points;
   int pos;
   tta_file_header_t header;
 
