@@ -14,10 +14,10 @@
 #ifndef __R_VC1_H
 #define __R_VC1_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "pr_generic.h"
-#include "vc1_common.h"
+#include "merge/pr_generic.h"
+#include "common/vc1.h"
 
 class vc1_es_reader_c: public generic_reader_c {
 private:
