@@ -12,19 +12,17 @@
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <ctype.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/os.h"
 
-#include "common.h"
-#include "mm_io.h"
-#include "output_control.h"
-#include "p_vobbtn.h"
-#include "r_vobbtn.h"
+#include "common/common.h"
+#include "common/endian.h"
+#include "common/mm_io.h"
+#include "common/strings/formatting.h"
+#include "common/strings/parsing.h"
+#include "input/r_vobbtn.h"
+#include "merge/output_control.h"
+#include "output/p_vobbtn.h"
 
-using namespace std;
 
 int
 vobbtn_reader_c::probe_file(mm_io_c *io,
