@@ -59,6 +59,7 @@
 #include "common/tags/tags.h"
 #include "common/tags/parser.h"
 #include "common/unique_numbers.h"
+#include "common/version.h"
 #include "merge/cluster_helper.h"
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
@@ -221,7 +222,7 @@ set_usage() {
                   "                           the id TID by 'd' ms.\n"
                   "                           'o/p': Adjust the timecodes by multiplying with\n"
                   "                           'o/p' to fix linear drifts. 'p' defaults to\n"
-                  "                           1000 if omitted. Both 'o' and 'p' can be\n"
+                  "                           1 if omitted. Both 'o' and 'p' can be\n"
                   "                           floating point numbers.\n");
   usage_text += Y("  --default-track <TID[:bool]>\n"
                   "                           Sets the 'default' flag for this track or\n"
@@ -298,7 +299,7 @@ set_usage() {
                   "explains several details in great length which are not obvious from\n"
                   "this listing.\n");
 
-  version_info = "mkvmerge v" VERSION " ('" VERSIONNAME "')";
+  version_info = get_version_info("mkvmerge", true);
 }
 
 /** \brief Prints information about what has been compiled into mkvmerge
@@ -509,23 +510,6 @@ parse_number_with_unit(const std::string &s,
     return (int64_t)(multiplier * d_value);
 }
 
-/** \brief Parse a string for a boolean value
-
-   Interpretes the string \c orig as a boolean value. Accepted
-   is "true", "yes", "1" as boolean true and "false", "no", "0"
-   as boolean false.
-*/
-bool
-parse_bool(const std::string &orig) {
-  std::string s(downcase(orig));
-
-  if ((s == "yes") || (s == "true") || (s == "1"))
-    return true;
-  if ((s == "no") || (s == "false") || (s == "0"))
-    return false;
-  throw false;
-}
-
 /** \brief Parse tags and add them to the list of all tags
 
    Also tests the tags for missing mandatory elements.
@@ -588,7 +572,7 @@ parse_arg_sync(std::string s,
   timecode_sync_t tcsync;
 
   // Extract the track number.
-  std::string orig          = s;
+  std::string orig               = s;
   std::vector<std::string> parts = split(s, ":", 2);
   if (parts.size() != 2)
     mxerror(boost::format(Y("Invalid sync option. No track ID specified in '%1% %2%'.\n")) % opt % s);
@@ -1602,7 +1586,7 @@ parse_args(std::vector<std::string> args) {
 
   }
 
-  mxinfo(boost::format(Y("%1% built on %2% %3%\n")) % version_info % __DATE__ % __TIME__);
+  mxinfo(boost::format("%1%\n") % get_version_info("mkvmerge", true));
 
   // Now parse options that are needed right at the beginning.
   mxforeach(sit, args) {
@@ -1634,8 +1618,9 @@ parse_args(std::vector<std::string> args) {
     usage(2);
   }
 
-  track_info_c *ti  = new track_info_c;
-  bool inputs_found = false;
+  track_info_c *ti      = new track_info_c;
+  bool inputs_found     = false;
+  bool append_next_file = false;
   attachment_t attachment;
 
   mxforeach(sit, args) {
@@ -2069,6 +2054,9 @@ parse_args(std::vector<std::string> args) {
     } else if (this_arg.length() == 0)
       mxerror(Y("An empty file name is not valid.\n"));
 
+    else if (this_arg == "+")
+      append_next_file = true;
+
     // The argument is an input file.
     else {
       if (g_outfile == this_arg)
@@ -2089,17 +2077,18 @@ parse_args(std::vector<std::string> args) {
 
       filelist_t file;
       if ('+' == this_arg[0]) {
-        file.name = this_arg.substr(1);
-        if (file.name.empty())
-          mxerror(Y("A single '+' is not a valid command line option. If you want to append a file "
-                    "use '+' directly followed by the file name, e.g. '+movie_part_2.avi'."));
+        append_next_file = true;
+        file.name        = this_arg.substr(1);
+      } else
+        file.name        = this_arg;
+
+      if (append_next_file) {
         if (g_files.empty())
           mxerror(Y("The first file cannot be appended because there are no files to append to.\n"));
 
-        file.appending = true;
-
-      } else
-        file.name = this_arg;
+        file.appending   = true;
+        append_next_file = false;
+      }
 
       ti->fname = file.name;
 
