@@ -35,6 +35,7 @@
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/translation.h"
+#include "common/version.h"
 #include "common/wx.h"
 #include "common/xml/element_mapping.h"
 #include "merge/mkvmerge.h"
@@ -61,8 +62,12 @@ std::vector<mmg_track_t *> tracks;
 std::map<wxString, wxString> capabilities;
 std::vector<job_t> jobs;
 
-mmg_dialog::mmg_dialog():
-  wxFrame(NULL, wxID_ANY, wxEmptyString) {
+mmg_dialog::mmg_dialog()
+  : wxFrame(NULL, wxID_ANY, wxEmptyString)
+#if defined(SYS_WINDOWS)
+  , m_taskbar_msg_received(false)
+#endif
+{
   wxBoxSizer *bs_main;
   wxPanel *panel;
 
@@ -78,7 +83,7 @@ mmg_dialog::mmg_dialog():
   app->init_ui_locale();
 #endif
 
-  SetTitle(wxString::Format(Z("mkvmerge GUI v%s ('%s')"), wxU(VERSION).c_str(), wxU(VERSIONNAME).c_str()));
+  SetTitle(wxU(get_version_info("mkvmerge GUI")));
 
   log_window = new wxLogWindow(this, Z("mmg debug output"), false);
   wxLog::SetActiveTarget(log_window);
@@ -216,6 +221,10 @@ mmg_dialog::mmg_dialog():
   help = NULL;
 
   set_status_bar(Z("mkvmerge GUI ready"));
+
+#if defined(SYS_WINDOWS)
+  RegisterWindowMessages();
+#endif
 }
 
 mmg_dialog::~mmg_dialog() {
@@ -510,7 +519,6 @@ mmg_dialog::display_help(int id) {
   if (help == NULL) {
     wxDirDialog dlg(this, Z("Choose the location of the mkvmerge GUI help files"));
     std::vector<wxString> potential_help_paths;
-    std::vector<wxString>::const_iterator php;
     wxString help_path;
     wxConfigBase *cfg;
     bool first;
@@ -551,9 +559,9 @@ mmg_dialog::display_help(int id) {
     potential_help_paths.push_back(wxGetCwd());
 
     help_path = wxEmptyString;
-    mxforeach(php, potential_help_paths)
-      if (wxFileExists(*php + wxT("/mkvmerge-gui.hhp"))) {
-        help_path = *php;
+    foreach(const wxString &php, potential_help_paths)
+      if (wxFileExists(php + wxT("/mkvmerge-gui.hhp"))) {
+        help_path = php;
         break;
       }
 
@@ -587,8 +595,7 @@ mmg_dialog::display_help(int id) {
 
 void
 mmg_dialog::on_about(wxCommandEvent &evt) {
-  wxMessageBox(wxString::Format(Z("mkvmerge GUI v%s ('%s')\n"
-                                  "built on %s %s\n\n"
+  wxMessageBox(wxString::Format(Z("%s\n\n"
                                   "This GUI was written by Moritz Bunkus <moritz@bunkus.org>"
                                   "\nBased on mmg by Florian Wagner <flo.wagner@gmx.de>\n"
                                   "mkvmerge GUI is licensed under the GPL.\n"
@@ -596,7 +603,7 @@ mmg_dialog::on_about(wxCommandEvent &evt) {
                                   "\n"
                                   "Help is available in form of tool tips, from the\n"
                                   "'Help' menu or by pressing the 'F1' key."),
-                                wxU(VERSION).c_str(), wxU(VERSIONNAME).c_str(), wxU(__DATE__).c_str(), wxU(__TIME__).c_str()),
+                                wxUCS(get_version_info("mkvmerge GUI", true))),
                Z("About mkvmerge's GUI"),
                wxOK | wxCENTER | wxICON_INFORMATION);
 }
@@ -699,7 +706,7 @@ mmg_dialog::update_command_line() {
 #if defined(HAVE_LIBINTL_H)
   if (!app->m_ui_locale.empty()) {
     clargs.Add(wxT("--ui-language"));
-    clargs.Add(wxCS2WS(app->m_ui_locale));
+    clargs.Add(wxU(app->m_ui_locale));
   }
 #endif  // HAVE_LIBINTL_H
 
@@ -1067,9 +1074,9 @@ mmg_dialog::update_file_menu() {
   wxString s;
 
   for (i = ID_M_FILE_LOADLAST1; i <= ID_M_FILE_LOADLAST4; i++) {
-    mi = file_menu->Remove(i);
+    mi = file_menu->FindItem(i);
     if (mi != NULL)
-      delete mi;
+      file_menu->Destroy(mi);
   }
 
   if ((last_settings.size() > 0) && !file_menu_sep) {
@@ -1089,9 +1096,9 @@ mmg_dialog::update_chapter_menu() {
   wxString s;
 
   for (i = ID_M_CHAPTERS_LOADLAST1; i <= ID_M_CHAPTERS_LOADLAST4; i++) {
-    mi = chapter_menu->Remove(i);
+    mi = chapter_menu->FindItem(i);
     if (mi != NULL)
-      delete mi;
+      chapter_menu->Destroy(mi);
   }
 
   if ((last_chapters.size() > 0) && !chapter_menu_sep) {
@@ -1158,13 +1165,12 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
     return;
 
   bool has_video = false, has_audio = false;
-  std::vector<mmg_track_t *>::iterator t;
 
-  mxforeach(t, tracks) {
-    if ('v' == (*t)->type) {
+  foreach(mmg_track_t *t, tracks) {
+    if (t->is_video()) {
       has_video = true;
       break;
-    } else if ('a' == (*t)->type)
+    } else if (t->is_audio())
       has_audio = true;
   }
 
@@ -1536,7 +1542,7 @@ mmg_dialog::query_mkvmerge_capabilities() {
     if (!out->Eof()) {
       c = out->GetC();
       if (c == '\n') {
-        output.Add(wxU(tmps.c_str()));
+        output.Add(wxU(tmps));
         tmps = "";
       } else if (c < 0)
         break;
@@ -1546,7 +1552,7 @@ mmg_dialog::query_mkvmerge_capabilities() {
       break;
   }
   if (tmps.length() > 0)
-    output.Add(wxU(tmps.c_str()));
+    output.Add(wxU(tmps));
   result = 0;
 #endif
 
