@@ -253,7 +253,7 @@ tab_input::select_file(bool append) {
   for (ae = 0; ae < all_extensions.size(); ae++) {
     if (a_exts.Length() > 0)
       a_exts += wxT(";");
-    a_exts += wxString::Format(wxT("*.%s"), all_extensions[ae].c_str());
+    a_exts += wxString::Format(wxT("*.%s;*.%s"), all_extensions[ae].c_str(), all_extensions[ae].Upper().c_str());
   }
 
   media_files.Printf(Z("All supported media files|%s%s|%s"), a_exts.c_str(), rest.c_str(), ALLFILES.c_str());
@@ -417,8 +417,8 @@ tab_input::add_file(const wxString &file_name,
             if ((dims.size() == 2) && parse_int(wxMB(dims[0]), width) && parse_int(wxMB(dims[1]), height)) {
               std::string format;
               fix_format(LLD, format);
-              track->dwidth.Printf(wxU(format.c_str()), width);
-              track->dheight.Printf(wxU(format.c_str()), height);
+              track->dwidth.Printf(wxU(format), width);
+              track->dheight.Printf(wxU(format), height);
               track->display_dimensions_selected = true;
             }
 
@@ -455,6 +455,7 @@ tab_input::add_file(const wxString &file_name,
       file->tracks.push_back(track);
 
       if (   (FILE_TYPE_AVC_ES == file->container)
+          && !track->appending
           && ('v' == track->type)
           && (track->ctype.Find(wxT("MPEG-4 part 10 ES")) >= 0)
           && (!avc_es_fps_warning_shown || mdlg->options.warn_usage)) {
@@ -942,7 +943,7 @@ tab_input::save(wxConfigBase *cfg) {
       s.Printf(wxT("%c"),                            t->type);
       cfg->Write(wxT("type"),                        s);
       fix_format("" LLD,                             format);
-      s.Printf(wxU(format.c_str()),                  t->id);
+      s.Printf(wxU(format),                          t->id);
       cfg->Write(wxT("id"),                          s);
       cfg->Write(wxT("enabled"),                     t->enabled);
       cfg->Write(wxT("content_type"),                t->ctype);
@@ -1101,7 +1102,7 @@ tab_input::load(wxConfigBase *cfg,
       tr->source = files.size();
       if (track_order.Length() > 0)
         track_order += wxT(",");
-      track_order += wxString::Format(wxUCS(format.c_str()), files.size(), tr->id);
+      track_order += wxString::Format(wxUCS(format), files.size(), tr->id);
 
       fi->tracks.push_back(tr);
       cfg->SetPath(wxT(".."));
@@ -1220,7 +1221,7 @@ tab_input::validate_settings() {
       std::string format;
       fix_format("%lld", format);
       wxString sid;
-      sid.Printf(wxU(format.c_str()), t->id);
+      sid.Printf(wxU(format), t->id);
 
       std::string s = wxMB(t->delay);
       strip(s);
@@ -1265,6 +1266,7 @@ tab_input::validate_settings() {
           return false;
         }
       } else if (   (FILE_TYPE_AVC_ES == f->container)
+                 && !t->appending
                  && ('v' == t->type)
                  && (t->ctype.Find(wxT("MPEG-4 part 10 ES")) >= 0)
                  && mdlg->options.warn_usage) {
