@@ -15,11 +15,11 @@
 #ifndef __P_DTS_H
 #define __P_DTS_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "dts_common.h"
+#include "common/common.h"
+#include "merge/pr_generic.h"
+#include "common/dts.h"
 
 class dts_packetizer_c: public generic_packetizer_c {
 private:
@@ -47,7 +47,7 @@ public:
     return "DTS";
   }
 
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 private:
   virtual void add_to_buffer(unsigned char *buf, int size);
