@@ -15,16 +15,16 @@
 #ifndef __P_KATE_H
 #define __P_KATE_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "smart_pointers.h"
-#include "kate_common.h"
+#include "common/common.h"
+#include "merge/pr_generic.h"
+#include "common/smart_pointers.h"
+#include "common/kate.h"
 
 class kate_packetizer_c: public generic_packetizer_c {
 private:
-  vector<memory_cptr> m_headers;
+  std::vector<memory_cptr> m_headers;
   memory_cptr m_global_data;
 
   kate_identification_header_t m_kate_id;
@@ -41,7 +41,7 @@ public:
   virtual const char *get_format_name() {
     return "Kate";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif  // __P_KATE_H
