@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_mp3.h 3209 2006-04-13 12:31:46Z mosu $
-
    class definition for the MP3 output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,24 +14,26 @@
 #ifndef __P_MP3_H
 #define __P_MP3_H
 
-#include "os.h"
+#include "common/os.h"
+#include "common/byte_buffer.h"
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "pr_generic.h"
-#include "mp3_common.h"
+#include "common/common.h"
+#include "common/mp3.h"
+#include "common/samples_timecode_conv.h"
+#include "merge/pr_generic.h"
 
 class mp3_packetizer_c: public generic_packetizer_c {
 private:
-  int64_t bytes_output, packetno, bytes_skipped;
-  int samples_per_sec, channels, spf;
-  byte_buffer_c byte_buffer;
-  bool codec_id_set, valid_headers_found;
+  int64_t m_bytes_output, m_packetno, m_bytes_skipped;
+  int m_samples_per_sec, m_channels, m_samples_per_frame;
+  byte_buffer_c m_byte_buffer;
+  bool m_codec_id_set, m_valid_headers_found;
+  int64_t m_previous_timecode, m_num_packets_with_same_timecode;
+  samples_to_timecode_converter_c m_s2tc;
+  int64_t m_single_packet_duration;
 
 public:
-  mp3_packetizer_c(generic_reader_c *_reader, int _samples_per_sec,
-                   int _channels, bool source_is_good, track_info_c &_ti)
-    throw (error_c);
+  mp3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, bool source_is_good) throw (error_c);
   virtual ~mp3_packetizer_c();
 
   virtual int process(packet_cptr packet);
@@ -42,13 +42,11 @@ public:
   virtual const char *get_format_name() {
     return "MP3";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 private:
   virtual unsigned char *get_mp3_packet(mp3_header_t *mp3header);
 
-  virtual void dump_debug_info();
   virtual void handle_garbage(int64_t bytes);
 };
 
