@@ -14,10 +14,10 @@
 #ifndef __P_PASSTHROUGH_H
 #define __P_PASSTHROUGH_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "common.h"
-#include "pr_generic.h"
+#include "common/common.h"
+#include "merge/pr_generic.h"
 
 class passthrough_packetizer_c: public generic_packetizer_c {
 public:
@@ -30,7 +30,7 @@ public:
   virtual const char *get_format_name() {
     return "passthrough";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_PASSTHROUGH_H
