@@ -14,11 +14,12 @@
 #ifndef __P_PCM_H
 #define __P_PCM_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "pr_generic.h"
+#include "common/byte_buffer.h"
+#include "common/common.h"
+#include "common/samples_timecode_conv.h"
+#include "merge/pr_generic.h"
 
 class pcm_packetizer_c: public generic_packetizer_c {
 private:
@@ -26,6 +27,7 @@ private:
   int64_t m_packet_size, m_samples_output;
   bool m_big_endian, m_ieee_float;
   byte_buffer_c m_buffer;
+  samples_to_timecode_converter_c m_s2tc;
 
 public:
   pcm_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int p_samples_per_sec, int channels, int bits_per_sample,
@@ -39,7 +41,7 @@ public:
   virtual const char *get_format_name() {
     return "PCM";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_PCM_H
