@@ -14,21 +14,21 @@
 #ifndef __P_TRUEHD_H
 #define __P_TRUEHD_H
 
-#include "os.h"
+#include "common/os.h"
 
 #include <vector>
 
-#include "common.h"
-#include "pr_generic.h"
-#include "samples_timecode_conv.h"
-#include "truehd_common.h"
+#include "common/common.h"
+#include "merge/pr_generic.h"
+#include "common/samples_timecode_conv.h"
+#include "common/truehd.h"
 
 class truehd_packetizer_c: public generic_packetizer_c {
 protected:
   bool m_first_frame;
   truehd_frame_t m_first_truehd_header;
 
-  int64_t m_samples_output, m_ref_timecode;
+  int64_t m_current_samples_per_frame, m_samples_output, m_ref_timecode;
   samples_to_timecode_converter_c m_s2tc;
   truehd_parser_c m_parser;
   std::vector<truehd_frame_cptr> m_frames;
@@ -47,7 +47,7 @@ public:
     return "TrueHD";
   }
 
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 protected:
   virtual void adjust_header_values(truehd_frame_cptr &frame);
