@@ -104,15 +104,15 @@ vc1_video_packetizer_c::add_timecodes_to_parser(packet_cptr &packet) {
   if (-1 != packet->timecode)
     m_parser.add_timecode(packet->timecode, 0);
 
-  std::vector<packet_extension_cptr>::iterator extensions_it;
-  mxforeach(extensions_it, packet->extensions) {
-    if ((*extensions_it)->get_type() == packet_extension_c::MULTIPLE_TIMECODES) {
-      multiple_timecodes_packet_extension_c *extension = static_cast<multiple_timecodes_packet_extension_c *>((*extensions_it).get_object());
-      int64_t timecode, position;
+  foreach(packet_extension_cptr &extension, packet->extensions) {
+    if (extension->get_type() != packet_extension_c::MULTIPLE_TIMECODES)
+      continue;
 
-      while (extension->get_next(timecode, position))
-        m_parser.add_timecode(timecode, position);
-    }
+    multiple_timecodes_packet_extension_c *tc_extension = static_cast<multiple_timecodes_packet_extension_c *>(extension.get_object());
+    int64_t timecode, position;
+
+    while (tc_extension->get_next(timecode, position))
+      m_parser.add_timecode(timecode, position);
   }
 }
 
