@@ -14,12 +14,12 @@
 #ifndef __P_VOBSUB_H
 #define __P_VOBSUB_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "common.h"
-#include "compression.h"
-#include "pr_generic.h"
-#include "smart_pointers.h"
+#include "common/common.h"
+#include "common/compression.h"
+#include "merge/pr_generic.h"
+#include "common/smart_pointers.h"
 
 class vobsub_packetizer_c: public generic_packetizer_c {
 private:
@@ -39,7 +39,7 @@ public:
     return "VobSub";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+                                             std::string &error_message);
 };
 
 #endif // __P_VOBSUB_H
